@@ -59,143 +59,6 @@ class CCDData(object):
     def shape(self):
         return self.image.shape
 
-    @classmethod
-    def simulate(cls, array, pixel_scale, exposure_time, psf=None, background_sky_level=None,
-                 add_noise=False, seed=-1, name=None):
-
-        exposure_time_map = ScaledSquarePixelArray.single_value(value=exposure_time, shape=array.shape,
-                                                                pixel_scale=pixel_scale)
-        if background_sky_level is not None:
-            background_sky_map = ScaledSquarePixelArray.single_value(value=background_sky_level, shape=array.shape,
-                                                                     pixel_scale=pixel_scale)
-        else:
-            background_sky_map = None
-
-        return cls.simulate_variable_arrays(array=array, pixel_scale=pixel_scale,
-                                            exposure_time_map=exposure_time_map, psf=psf,
-                                            background_sky_map=background_sky_map,
-                                            add_noise=add_noise, seed=seed, name=name)
-
-    @classmethod
-    def simulate_variable_arrays(cls, array, pixel_scale, exposure_time_map, psf=None, background_sky_map=None,
-                                 add_noise=True, seed=-1, name=None):
-        """
-        Create a realistic simulated image by applying effects to a plain simulated image.
-
-        Parameters
-        ----------
-        name
-        array : ndarray
-            The image before simulating (e.g. the lens and source galaxies before optics blurring and CCD read-out).
-        pixel_scale: float
-            The scale of each pixel in arc seconds
-        exposure_time_map : ndarray
-            An array representing the effective exposure time of each pixel.
-        psf: PSF
-            An array describing the PSF the simulated image is blurred with.
-        background_sky_map : ndarray
-            The value of background sky in every image pixel (electrons per second).
-        add_noise: Bool
-            If True poisson noise_maps is simulated and added to the image, based on the total counts in each image
-            pixel
-        seed: int
-            A seed for random noise_maps generation
-        """
-
-        if background_sky_map is not None:
-            array += background_sky_map
-
-        if psf is not None:
-            array = psf.convolve(array)
-            array = cls.trim_psf_edges(array, psf)
-            exposure_time_map = cls.trim_psf_edges(exposure_time_map, psf)
-            if background_sky_map is not None:
-                background_sky_map = cls.trim_psf_edges(background_sky_map, psf)
-
-        if add_noise is True:
-            array += generate_poisson_noise(array, exposure_time_map, seed)
-            array_counts = np.multiply(array, exposure_time_map)
-            noise_map = np.divide(np.sqrt(array_counts), exposure_time_map)
-        else:
-            noise_map = None
-
-        if background_sky_map is not None:
-            array -= background_sky_map
-
-        # ESTIMATE THE BACKGROUND NOISE MAP FROM THE IMAGE
-
-        if background_sky_map is not None:
-            background_noise_map_counts = np.sqrt(np.multiply(background_sky_map, exposure_time_map))
-            background_noise_map = np.divide(background_noise_map_counts, exposure_time_map)
-        else:
-            background_noise_map = None
-
-        # ESTIMATE THE POISSON NOISE MAP FROM THE IMAGE
-
-        array_counts = np.multiply(array, exposure_time_map)
-        poisson_noise_map = np.divide(np.sqrt(np.abs(array_counts)), exposure_time_map)
-
-        array = ScaledSquarePixelArray(array=array, pixel_scale=pixel_scale)
-        noise_map = NoiseMap(array=noise_map, pixel_scale=pixel_scale)
-
-        if background_noise_map is not None:
-            background_noise_map = NoiseMap(array=background_noise_map, pixel_scale=pixel_scale)
-
-        if poisson_noise_map is not None:
-            poisson_noise_map = PoissonNoiseMap(array=poisson_noise_map, pixel_scale=pixel_scale)
-
-        return CCDData(array, pixel_scale=pixel_scale, psf=psf, noise_map=noise_map,
-                       background_noise_map=background_noise_map, poisson_noise_map=poisson_noise_map,
-                       exposure_time_map=exposure_time_map, background_sky_map=background_sky_map, name=name)
-
-    @classmethod
-    def simulate_to_target_signal_to_noise(cls, array, pixel_scale, target_signal_to_noise, exposure_time_map,
-                                           psf=None, background_sky_map=None, seed=-1):
-        """
-        Create a realistic simulated image by applying effects to a plain simulated image.
-
-        Parameters
-        ----------
-        target_signal_to_noise
-        array : ndarray
-            The image before simulating (e.g. the lens and source galaxies before optics blurring and CCD read-out).
-        pixel_scale: float
-            The scale of each pixel in arc seconds
-        exposure_time_map : ndarray
-            An array representing the effective exposure time of each pixel.
-        psf: PSF
-            An array describing the PSF the simulated image is blurred with.
-        background_sky_map : ndarray
-            The value of background sky in every image pixel (electrons per second).
-        seed: int
-            A seed for random noise_maps generation
-        """
-
-        max_index = np.unravel_index(array.argmax(), array.shape)
-        max_image = array[max_index]
-        max_effective_exposure_time = exposure_time_map[max_index]
-        max_array_counts = np.multiply(max_image, max_effective_exposure_time)
-        if background_sky_map is not None:
-            max_background_sky_map = background_sky_map[max_index]
-            max_background_sky_map_counts = np.multiply(max_background_sky_map, max_effective_exposure_time)
-        else:
-            max_background_sky_map_counts = None
-
-        scale_factor = 1.
-
-        if background_sky_map is None:
-            scale_factor = target_signal_to_noise ** 2.0 / max_array_counts
-        elif background_sky_map is not None:
-            scale_factor = (max_array_counts + max_background_sky_map_counts) * target_signal_to_noise ** 2.0 \
-                           / max_array_counts ** 2.0
-
-        scaled_effective_exposure_time = np.multiply(scale_factor, exposure_time_map)
-
-        return cls.simulate_variable_arrays(array=array, pixel_scale=pixel_scale,
-                                            exposure_time_map=scaled_effective_exposure_time,
-                                            psf=psf, background_sky_map=background_sky_map,
-                                            add_noise=True, seed=seed)
-
     def new_ccd_data_with_binned_up_arrays(self, bin_up_factor):
 
         image = self.bin_up_scaled_array(scaled_array=self.image, bin_up_factor=bin_up_factor, method='mean')
@@ -277,9 +140,11 @@ class CCDData(object):
 
     def new_ccd_data_with_poisson_noise_added(self, seed=-1):
 
+        from autolens.data import simulated_ccd
+
         image_with_sky = self.image + self.background_sky_map
 
-        image_with_sky_and_noise = image_with_sky + generate_poisson_noise(image=image_with_sky,
+        image_with_sky_and_noise = image_with_sky + simulated_ccd.generate_poisson_noise(image=image_with_sky,
                                                                            exposure_time_map=self.exposure_time_map,
                                                                            seed=seed)
 
@@ -348,17 +213,6 @@ class CCDData(object):
         """The maximum value of the potential chi-squared map"""
         return np.max(self.potential_chi_squared_map)
 
-    @staticmethod
-    def trim_psf_edges(array, psf):
-        if psf is not None:
-            psf_cut_x = np.int(np.ceil(psf.shape[0] / 2)) - 1
-            psf_cut_y = np.int(np.ceil(psf.shape[1] / 2)) - 1
-            array_x = np.int(array.shape[0])
-            array_y = np.int(array.shape[1])
-            return array[psf_cut_x:array_x - psf_cut_x, psf_cut_y:array_y - psf_cut_y]
-        else:
-            return array
-
     def array_from_electrons_per_second_to_counts(self, array):
         """
         For an array (in electrons per second) and an exposure time mappers, return an array in units counts.
@@ -560,21 +414,29 @@ class PSF(ScaledSquarePixelArray):
             self[:, :] = np.divide(self, np.sum(self))
 
     @classmethod
-    def simulate_as_gaussian(cls, shape, pixel_scale, sigma, centre=(0.0, 0.0), axis_ratio=1.0, phi=0.0):
+    def from_no_blurring_kernel(cls, pixel_scale):
+
+        array = np.array([[0.0, 0.0, 0.0],
+                          [0.0, 1.0, 0.0],
+                          [0.0, 0.0, 0.0]])
+
+        return PSF(array=array, pixel_scale=pixel_scale, renormalize=False)
+
+    @classmethod
+    def from_gaussian(cls, shape, pixel_scale, sigma, centre=(0.0, 0.0), axis_ratio=1.0, phi=0.0):
         """Simulate the PSF as an elliptical Gaussian profile."""
         from autolens.model.profiles.light_profiles import EllipticalGaussian
         gaussian = EllipticalGaussian(centre=centre, axis_ratio=axis_ratio, phi=phi, intensity=1.0, sigma=sigma)
-        grid_1d = grid_util.regular_grid_1d_masked_from_mask_pixel_scales_and_origin(mask=np.full(shape, False),
-                                                                                     pixel_scales=(
-                                                                                         pixel_scale, pixel_scale))
+        grid_1d = grid_util.regular_grid_1d_masked_from_mask_pixel_scales_and_origin(
+            mask=np.full(shape, False), pixel_scales=(pixel_scale, pixel_scale))
         gaussian_1d = gaussian.intensities_from_grid(grid=grid_1d)
-        gaussian_2d = mapping_util.map_unmasked_1d_array_to_2d_array_from_array_1d_and_shape(array_1d=gaussian_1d,
-                                                                                             shape=shape)
+        gaussian_2d = mapping_util.map_unmasked_1d_array_to_2d_array_from_array_1d_and_shape(
+            array_1d=gaussian_1d, shape=shape)
         return PSF(array=gaussian_2d, pixel_scale=pixel_scale, renormalize=True)
 
     @classmethod
-    def simulate_as_gaussian_via_alma_fits_header_parameters(cls, shape, pixel_scale, y_stddev, x_stddev, theta,
-                                                             centre=(0.0, 0.0)):
+    def from_as_gaussian_via_alma_fits_header_parameters(cls, shape, pixel_scale, y_stddev, x_stddev, theta,
+                                                         centre=(0.0, 0.0)):
 
         x_stddev = x_stddev * (units.deg).to(units.arcsec) / (2.0 * np.sqrt(2.0 * np.log(2.0)))
         y_stddev = y_stddev * (units.deg).to(units.arcsec) / (2.0 * np.sqrt(2.0 * np.log(2.0)))
@@ -629,6 +491,7 @@ class PSF(ScaledSquarePixelArray):
         return cls(array=array_util.numpy_array_2d_from_fits(file_path, hdu), pixel_scale=pixel_scale)
 
     def new_psf_with_rescaled_odd_dimensioned_array(self, rescale_factor, renormalize=True):
+
         psf_rescaled = rescale(self, rescale_factor, anti_aliasing=False, mode='constant', multichannel=False)
 
         if psf_rescaled.shape[0] % 2 == 0 and psf_rescaled.shape[1] % 2 == 0:
@@ -681,46 +544,6 @@ class ExposureTimeMap(ScaledSquarePixelArray):
         return ExposureTimeMap(array=np.abs(exposure_time * (relative_background_noise_map)), pixel_scale=pixel_scale)
 
 
-def setup_random_seed(seed):
-    """Setup the random seed. If the input seed is -1, the code will use a random seed for every run. If it is \
-    positive, that seed is used for all runs, thereby giving reproducible results.
-
-    Parameters
-    ----------
-    seed : int
-        The seed of the random number generator.
-    """
-    if seed == -1:
-        seed = np.random.randint(0,
-                                 int(1e9))  # Use one seed, so all regions have identical column non-uniformity.
-    np.random.seed(seed)
-
-
-def generate_poisson_noise(image, exposure_time_map, seed=-1):
-    """
-    Generate a two-dimensional poisson noise_maps-mappers from an image.
-
-    Values are computed from a Poisson distribution using the image's input values in units of counts.
-
-    Parameters
-    ----------
-    image : ndarray
-        The 2D image, whose values in counts are used to draw Poisson noise_maps values.
-    exposure_time_map : Union(ndarray, int)
-        2D array of the exposure time in each pixel used to convert to / from counts and electrons per second.
-    seed : int
-        The seed of the random number generator, used for the random noise_maps maps.
-
-    Returns
-    -------
-    poisson_noise_map: ndarray
-        An array describing simulated poisson noise_maps
-    """
-    setup_random_seed(seed)
-    image_counts = np.multiply(image, exposure_time_map)
-    return image - np.divide(np.random.poisson(image_counts, image.shape), exposure_time_map)
-
-
 def load_ccd_data_from_fits(image_path, pixel_scale, image_hdu=0,
                             resized_ccd_shape=None, resized_ccd_origin_pixels=None,
                             resized_ccd_origin_arcsec=None,
@@ -973,7 +796,7 @@ def load_noise_map(noise_map_path, noise_map_hdu, pixel_scale, image, background
                              noise_map_from_image_and_background_noise_map])
 
     if noise_map_options > 1:
-        raise exc.ImagingException('You have specified more than one method to load the noise_map map, e.g.:'
+        raise exc.DataException('You have specified more than one method to load the noise_map map, e.g.:'
                                    'convert_noise_map_from_weight_map | '
                                    'convert_noise_map_from_inverse_noise_map |'
                                    'noise_map_from_image_and_background_noise_map')
@@ -989,15 +812,15 @@ def load_noise_map(noise_map_path, noise_map_hdu, pixel_scale, image, background
     elif noise_map_from_image_and_background_noise_map:
 
         if background_noise_map is None:
-            raise exc.ImagingException('Cannot compute the noise-map from the image and background noise_map map if a '
+            raise exc.DataException('Cannot compute the noise-map from the image and background noise_map map if a '
                                        'background noise_map map is not supplied.')
 
         if not (convert_from_electrons or convert_from_adus) and exposure_time_map is None:
-            raise exc.ImagingException('Cannot compute the noise-map from the image and background noise_map map if an '
+            raise exc.DataException('Cannot compute the noise-map from the image and background noise_map map if an '
                                        'exposure-time (or exposure time map) is not supplied to convert to adus')
 
         if convert_from_adus and gain is None:
-            raise exc.ImagingException('Cannot compute the noise-map from the image and background noise_map map if a'
+            raise exc.DataException('Cannot compute the noise-map from the image and background noise_map map if a'
                                        'gain is not supplied to convert from adus')
 
         return NoiseMap.from_image_and_background_noise_map(pixel_scale=pixel_scale, image=image,
@@ -1006,7 +829,7 @@ def load_noise_map(noise_map_path, noise_map_hdu, pixel_scale, image, background
                                                             convert_from_electrons=convert_from_electrons,
                                                             gain=gain, convert_from_adus=convert_from_adus)
     else:
-        raise exc.ImagingException(
+        raise exc.DataException(
             'A noise_map map was not loaded, specify a noise_map_path or option to compute a noise_map map.')
 
 
@@ -1102,11 +925,11 @@ def load_poisson_noise_map(poisson_noise_map_path, poisson_noise_map_hdu, pixel_
     elif poisson_noise_map_from_image:
 
         if not (convert_from_electrons or convert_from_adus) and exposure_time_map is None:
-            raise exc.ImagingException('Cannot compute the Poisson noise-map from the image if an '
+            raise exc.DataException('Cannot compute the Poisson noise-map from the image if an '
                                        'exposure-time (or exposure time map) is not supplied to convert to adus')
 
         if convert_from_adus and gain is None:
-            raise exc.ImagingException('Cannot compute the Poisson noise-map from the image if a'
+            raise exc.DataException('Cannot compute the Poisson noise-map from the image if a'
                                        'gain is not supplied to convert from adus')
 
         return PoissonNoiseMap.from_image_and_exposure_time_map(pixel_scale=pixel_scale, image=image,
@@ -1174,7 +997,7 @@ def load_exposure_time_map(exposure_time_map_path, exposure_time_map_hdu, pixel_
     exposure_time_map_options = sum([exposure_time_map_from_inverse_noise_map])
 
     if exposure_time is not None and exposure_time_map_path is not None:
-        raise exc.ImagingException(
+        raise exc.DataException(
             'You have supplied both a exposure_time_map_path to an exposure time map and an exposure time. Only'
             'one quantity should be supplied.')
 
