@@ -1,14 +1,16 @@
+import autofit as af
+import matplotlib
+backend = af.conf.instance.visualize.get('figures', 'backend', str)
+matplotlib.use(backend)
 from matplotlib import pyplot as plt
 
-from autofit import conf
 from autolens.data.plotters import data_plotters
-from autolens.data.array.plotters import plotter_util
-
+from autolens.plotters import plotter_util
 
 def plot_ccd_subplot(
         ccd_data, plot_origin=True, mask=None, extract_array_from_mask=False, zoom_around_mask=False,
         should_plot_border=False, positions=None,
-        units='arcsec', kpc_per_arcsec=None, figsize=None, aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=None, aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         titlesize=10, xlabelsize=10, ylabelsize=10, xyticksize=10,
@@ -191,10 +193,10 @@ def plot_ccd_individual(
             output_path=output_path, output_format=output_format)
 
 def plot_image(
-        ccd_data, plot_origin=True, mask=None, extract_array_from_mask=False, zoom_around_mask=False,
+        ccd_data, plot_origin=True, grid=None, mask=None, extract_array_from_mask=False, zoom_around_mask=False,
         should_plot_border=False, positions=None,
         as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='CCD Image', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -215,7 +217,8 @@ def plot_image(
         over the immage.
     """
     data_plotters.plot_image(
-        image=ccd_data.image, plot_origin=plot_origin, mask=mask, extract_array_from_mask=extract_array_from_mask,
+        image=ccd_data.image, plot_origin=plot_origin, grid=grid, mask=mask,
+        extract_array_from_mask=extract_array_from_mask,
         zoom_around_mask=zoom_around_mask, should_plot_border=should_plot_border, positions=positions,
         as_subplot=as_subplot,
         units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
@@ -229,7 +232,7 @@ def plot_image(
 
 def plot_noise_map(
         ccd_data, plot_origin=True, mask=None, extract_array_from_mask=False, zoom_around_mask=False, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='CCD Noise-Map', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16, mask_pointsize=10,
@@ -260,7 +263,7 @@ def plot_noise_map(
 
 def plot_psf(
         ccd_data, plot_origin=True, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='CCD PSF', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -289,7 +292,7 @@ def plot_psf(
 
 def plot_signal_to_noise_map(
         ccd_data, plot_origin=True, mask=None, extract_array_from_mask=False, zoom_around_mask=False, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='CCD Signal-To-Noise-Map', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -321,7 +324,7 @@ def plot_signal_to_noise_map(
 
 def plot_absolute_signal_to_noise_map(
         ccd_data, plot_origin=True, mask=None, extract_array_from_mask=False, zoom_around_mask=False, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='CCD Absolute Signal-To-Noise-Map', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -353,7 +356,7 @@ def plot_absolute_signal_to_noise_map(
 
 def plot_potential_chi_squared_map(
         ccd_data, plot_origin=True, mask=None, extract_array_from_mask=False, zoom_around_mask=False, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='CCD Potential Chi-Squared Map', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
