@@ -1,6 +1,6 @@
 import numba
 
-from autofit import conf
+import autofit as af
 
 """
 Depending on if we're using a super computer, we want two different numba decorators:
@@ -14,9 +14,9 @@ If on super computer:
 @numba.jit(nopython=True, cache=False, parallel=True)
 """
 
-nopython = conf.instance.general.get("numba", "nopython", bool)
-cache = conf.instance.general.get("numba", "cache", bool)
-parallel = conf.instance.general.get("numba", "parallel", bool)
+nopython = af.conf.instance.general.get("numba", "nopython", bool)
+cache = af.conf.instance.general.get("numba", "cache", bool)
+parallel = af.conf.instance.general.get("numba", "parallel", bool)
 
 
 def jit(nopython=nopython, cache=cache, parallel=parallel):
@@ -24,3 +24,4 @@ def jit(nopython=nopython, cache=cache, parallel=parallel):
         return numba.jit(func, nopython=nopython, cache=cache, parallel=parallel)
 
     return wrapper
+
