@@ -1,11 +1,11 @@
-from autofit import exc
+import autofit as af
 
 
 class ScaledArrayException(Exception):
     pass
 
 
-class ImagingException(Exception):
+class DataException(Exception):
     pass
 
 
@@ -17,19 +17,23 @@ class MaskException(Exception):
     pass
 
 
+class CosmologyException(Exception):
+    pass
+
+
 class GalaxyException(Exception):
     pass
 
 
-class RayTracingException(exc.FitException):
+class RayTracingException(af.exc.FitException):
     pass
 
 
-class PixelizationException(exc.FitException):
+class PixelizationException(af.exc.FitException):
     pass
 
 
-class InversionException(exc.FitException):
+class InversionException(af.exc.FitException):
     pass
 
 
@@ -42,4 +46,8 @@ class PlottingException(Exception):
 
 
 class PhaseException(Exception):
-    pass
\ No newline at end of file
+    pass
+
+
+class UnitsException(Exception):
+    pass
