@@ -1,12 +1,11 @@
+from autolens.plotters import array_plotters
 from autolens import exc
-from autolens.data.array.plotters import array_plotters
 
-import numpy as np
 
 def plot_image(
-        fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None,
-        image_plane_pix_grid=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False,
+        positions=None, grid=None, as_subplot=False,
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='Fit Image', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -25,8 +24,8 @@ def plot_image(
     """
 
     array_plotters.plot_array(
-        array=fit.image, mask=mask, extract_array_from_mask=extract_array_from_mask,
-        zoom_around_mask=zoom_around_mask, grid=image_plane_pix_grid,
+        array=fit.image_2d, mask=mask, extract_array_from_mask=extract_array_from_mask,
+        zoom_around_mask=zoom_around_mask,
         positions=positions, as_subplot=as_subplot,
         units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
         cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
@@ -38,7 +37,7 @@ def plot_image(
 
 def plot_noise_map(
         fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='Fit Noise-Map', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -56,7 +55,7 @@ def plot_noise_map(
         If true, the origin of the datas's coordinate system is plotted as a 'x'.
     """
     array_plotters.plot_array(
-        array=fit.noise_map, mask=mask, extract_array_from_mask=extract_array_from_mask,
+        array=fit.noise_map_2d, mask=mask, extract_array_from_mask=extract_array_from_mask,
         zoom_around_mask=zoom_around_mask,
         positions=positions, as_subplot=as_subplot,
         units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
@@ -69,7 +68,7 @@ def plot_noise_map(
 
 def plot_signal_to_noise_map(
         fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='Fit Signal-to-Noise-Map', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -87,7 +86,7 @@ def plot_signal_to_noise_map(
     If true, the origin of the datas's coordinate system is plotted as a 'x'.
     """
     array_plotters.plot_array(
-        array=fit.signal_to_noise_map, mask=mask, extract_array_from_mask=extract_array_from_mask,
+        array=fit.signal_to_noise_map_2d, mask=mask, extract_array_from_mask=extract_array_from_mask,
         zoom_around_mask=zoom_around_mask, positions=positions, as_subplot=as_subplot,
         units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
         cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max,
@@ -99,8 +98,9 @@ def plot_signal_to_noise_map(
         output_path=output_path, output_format=output_format, output_filename=output_filename)
 
 def plot_model_data(
-        fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None,
+        plot_mass_profile_centres=True, as_subplot=False,
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='Fit Model Image', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -117,97 +117,12 @@ def plot_model_data(
     image_index : int
         The index of the datas in the datas-set of which the model image is plotted.
     """
-    array_plotters.plot_array(
-        array=fit.model_data, mask=mask, extract_array_from_mask=extract_array_from_mask,
-        zoom_around_mask=zoom_around_mask, positions=positions, as_subplot=as_subplot,
-        units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
-        cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
-        cb_ticksize=cb_ticksize, cb_fraction=cb_fraction, cb_pad=cb_pad, 
-        cb_tick_values=cb_tick_values, cb_tick_labels=cb_tick_labels,
-        title=title, titlesize=titlesize, xlabelsize=xlabelsize, ylabelsize=ylabelsize, xyticksize=xyticksize,
-        mask_pointsize=mask_pointsize, position_pointsize=position_pointsize,
-        output_path=output_path, output_format=output_format, output_filename=output_filename)
 
-def plot_lens_subtracted_image(
-        fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
-        cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
-        cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
-        title='Fit Model Image', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
-        mask_pointsize=10, position_pointsize=10,
-        output_path=None, output_format='show', output_filename='fit_lens_subtracted_image'):
-    """Plot the model image of a specific plane of a lens fit.
-
-    Set *autolens.datas.array.plotters.array_plotters* for a description of all input parameters not described below.
-
-    Parameters
-    -----------
-    fit : datas.fitting.fitting.AbstractFitter
-        The fit to the datas, which includes a list of every model image, residual_map, chi-squareds, etc.
-    image_index : int
-        The index of the datas in the datas-set of which the model image is plotted.
-    plane_indexes : int
-        The plane from which the model image is generated.
-    """
-
-    if fit.tracer.total_planes == 2:
-        if fit.tracer.image_plane.has_light_profile:
-            lens_subtracted_image = fit.image - fit.model_image_of_planes[0]
-        else:
-            lens_subtracted_image = fit.image
-    else:
-        lens_subtracted_image = fit.image - sum(fit.model_image_of_planes[0:-2])
+    centres = get_mass_profile_centes(plot_mass_profile_centres=plot_mass_profile_centres, fit=fit)
 
     array_plotters.plot_array(
-        array=lens_subtracted_image, mask=mask, extract_array_from_mask=extract_array_from_mask,
-        zoom_around_mask=zoom_around_mask, positions=positions, as_subplot=as_subplot,
-        units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
-        cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
-        cb_ticksize=cb_ticksize, cb_fraction=cb_fraction, cb_pad=cb_pad, 
-        cb_tick_values=cb_tick_values, cb_tick_labels=cb_tick_labels,
-        title=title, titlesize=titlesize, xlabelsize=xlabelsize, ylabelsize=ylabelsize, xyticksize=xyticksize,
-        mask_pointsize=mask_pointsize, position_pointsize=position_pointsize,
-        output_path=output_path, output_format=output_format, output_filename=output_filename)
-
-def plot_model_image_of_planes(
-        fit, plot_foreground=False, plot_source=False, mask=None, extract_array_from_mask=False, zoom_around_mask=False,
-        positions=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
-        cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
-        cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
-        title='Fit Model Image', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
-        mask_pointsize=10, position_pointsize=10,
-        output_path=None, output_format='show', output_filename='fit_model_image_of_plane'):
-    """Plot the model image of a specific plane of a lens fit.
-
-    Set *autolens.datas.array.plotters.array_plotters* for a description of all input parameters not described below.
-
-    Parameters
-    -----------
-    fit : datas.fitting.fitting.AbstractFitter
-        The fit to the datas, which includes a list of every model image, residual_map, chi-squareds, etc.
-    plane_indexes : [int]
-        The plane from which the model image is generated.
-    """
-
-    if plot_foreground:
-
-        if fit.tracer.total_planes == 2:
-            model_image = fit.model_image_of_planes[0]
-        else:
-            model_image = sum(fit.model_image_of_planes[0:-2])
-
-    elif plot_source:
-
-        model_image = fit.model_image_of_planes[-1]
-
-    else:
-
-        raise exc.PlottingException('Both plot_foreground and plot_source were False, one must be True')
-
-    array_plotters.plot_array(
-        array=model_image, mask=mask, extract_array_from_mask=extract_array_from_mask,
-        zoom_around_mask=zoom_around_mask, positions=positions, as_subplot=as_subplot,
+        array=fit.model_image_2d, mask=mask, extract_array_from_mask=extract_array_from_mask,
+        zoom_around_mask=zoom_around_mask, positions=positions, centres=centres, as_subplot=as_subplot,
         units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
         cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
         cb_ticksize=cb_ticksize, cb_fraction=cb_fraction, cb_pad=cb_pad, 
@@ -218,7 +133,7 @@ def plot_model_image_of_planes(
 
 def plot_residual_map(
         fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='Fit Residuals', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -236,7 +151,37 @@ def plot_residual_map(
         The index of the datas in the datas-set of which the residual_map are plotted.
     """
     array_plotters.plot_array(
-        array=fit.residual_map, mask=mask, extract_array_from_mask=extract_array_from_mask,
+        array=fit.residual_map_2d, mask=mask, extract_array_from_mask=extract_array_from_mask,
+        zoom_around_mask=zoom_around_mask, positions=positions, as_subplot=as_subplot,
+        units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
+        cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
+        cb_ticksize=cb_ticksize, cb_fraction=cb_fraction, cb_pad=cb_pad, 
+        cb_tick_values=cb_tick_values, cb_tick_labels=cb_tick_labels,
+        title=title, titlesize=titlesize, xlabelsize=xlabelsize, ylabelsize=ylabelsize, xyticksize=xyticksize,
+        mask_pointsize=mask_pointsize, position_pointsize=position_pointsize,
+        output_path=output_path, output_format=output_format, output_filename=output_filename)
+
+def plot_normalized_residual_map(
+        fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None, as_subplot=False,
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
+        cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
+        cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
+        title='Fit Normalized Residuals', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
+        mask_pointsize=10, position_pointsize=10,
+        output_path=None, output_format='show', output_filename='fit_normalized_residual_map'):
+    """Plot the residual-map of a lens fit.
+
+    Set *autolens.datas.array.plotters.array_plotters* for a description of all input parameters not described below.
+
+    Parameters
+    -----------
+    fit : datas.fitting.fitting.AbstractFitter
+        The fit to the datas, which includes a list of every model image, normalized_residual_map, chi-squareds, etc.
+    image_index : int
+        The index of the datas in the datas-set of which the normalized_residual_map are plotted.
+    """
+    array_plotters.plot_array(
+        array=fit.normalized_residual_map_2d, mask=mask, extract_array_from_mask=extract_array_from_mask,
         zoom_around_mask=zoom_around_mask, positions=positions, as_subplot=as_subplot,
         units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
         cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
@@ -248,7 +193,7 @@ def plot_residual_map(
 
 def plot_chi_squared_map(
         fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='Fit Chi-Squareds', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -266,7 +211,7 @@ def plot_chi_squared_map(
         The index of the datas in the datas-set of which the chi-squareds are plotted.
     """
     array_plotters.plot_array(
-        array=fit.chi_squared_map, mask=mask, extract_array_from_mask=extract_array_from_mask,
+        array=fit.chi_squared_map_2d, mask=mask, extract_array_from_mask=extract_array_from_mask,
         zoom_around_mask=zoom_around_mask, positions=positions, as_subplot=as_subplot,
         units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
         cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
@@ -276,9 +221,92 @@ def plot_chi_squared_map(
         mask_pointsize=mask_pointsize, position_pointsize=position_pointsize,
         output_path=output_path, output_format=output_format, output_filename=output_filename)
 
+def plot_subtracted_image_of_plane(
+        fit, plane_index, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None,
+        image_plane_pix_grid=None, as_subplot=False,
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
+        cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
+        cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
+        title='Fit Model Image', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
+        mask_pointsize=10, position_pointsize=10,
+        output_path=None, output_format='show', output_filename='fit_subtracted_image_of_plane'):
+    """Plot the model image of a specific plane of a lens fit.
+
+    Set *autolens.datas.array.plotters.array_plotters* for a description of all input parameters not described below.
+
+    Parameters
+    -----------
+    fit : datas.fitting.fitting.AbstractFitter
+        The fit to the datas, which includes a list of every model image, residual_map, chi-squareds, etc.
+    image_index : int
+        The index of the datas in the datas-set of which the model image is plotted.
+    plane_indexes : int
+        The plane from which the model image is generated.
+    """
+
+    output_filename += '_' + str(plane_index)
+
+    if fit.tracer.total_planes > 1:
+
+        other_planes_model_images_2d = \
+            [model_image_2d for i, model_image_2d in enumerate(fit.model_image_2d_of_planes) if i != plane_index]
+
+        subtracted_image = fit.image_2d - sum(other_planes_model_images_2d)
+
+    else:
+
+        subtracted_image = fit.image_2d
+
+    array_plotters.plot_array(
+        array=subtracted_image, mask=mask, extract_array_from_mask=extract_array_from_mask, grid=image_plane_pix_grid,
+        zoom_around_mask=zoom_around_mask, positions=positions, as_subplot=as_subplot,
+        units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
+        cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
+        cb_ticksize=cb_ticksize, cb_fraction=cb_fraction, cb_pad=cb_pad,
+        cb_tick_values=cb_tick_values, cb_tick_labels=cb_tick_labels,
+        title=title, titlesize=titlesize, xlabelsize=xlabelsize, ylabelsize=ylabelsize, xyticksize=xyticksize,
+        mask_pointsize=mask_pointsize, position_pointsize=position_pointsize,
+        output_path=output_path, output_format=output_format, output_filename=output_filename)
+
+def plot_model_image_of_plane(
+        fit, plane_index, mask=None, extract_array_from_mask=False, zoom_around_mask=False,
+        positions=None, plot_mass_profile_centres=True, as_subplot=False,
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
+        cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
+        cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
+        title='Model Image', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
+        mask_pointsize=10, position_pointsize=10,
+        output_path=None, output_format='show', output_filename='fit_model_image_of_plane'):
+    """Plot the model image of a specific plane of a lens fit.
+
+    Set *autolens.datas.array.plotters.array_plotters* for a description of all input parameters not described below.
+
+    Parameters
+    -----------
+    fit : datas.fitting.fitting.AbstractFitter
+        The fit to the datas, which includes a list of every model image, residual_map, chi-squareds, etc.
+    plane_indexes : [int]
+        The plane from which the model image is generated.
+    """
+
+    output_filename += '_' + str(plane_index)
+
+    centres = get_mass_profile_centes(plot_mass_profile_centres=plot_mass_profile_centres, fit=fit)
+
+    array_plotters.plot_array(
+        array=fit.model_image_2d_of_planes[plane_index], mask=mask, extract_array_from_mask=extract_array_from_mask,
+        zoom_around_mask=zoom_around_mask, positions=positions, centres=centres, as_subplot=as_subplot,
+        units=units, kpc_per_arcsec=kpc_per_arcsec, figsize=figsize, aspect=aspect,
+        cmap=cmap, norm=norm, norm_min=norm_min, norm_max=norm_max, linthresh=linthresh, linscale=linscale,
+        cb_ticksize=cb_ticksize, cb_fraction=cb_fraction, cb_pad=cb_pad,
+        cb_tick_values=cb_tick_values, cb_tick_labels=cb_tick_labels,
+        title=title, titlesize=titlesize, xlabelsize=xlabelsize, ylabelsize=ylabelsize, xyticksize=xyticksize,
+        mask_pointsize=mask_pointsize, position_pointsize=position_pointsize,
+        output_path=output_path, output_format=output_format, output_filename=output_filename)
+
 def plot_contribution_maps(
         fit, mask=None, extract_array_from_mask=False, zoom_around_mask=False, positions=None, as_subplot=False,
-        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='equal',
+        units='arcsec', kpc_per_arcsec=None, figsize=(7, 7), aspect='square',
         cmap='jet', norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
         cb_ticksize=10, cb_fraction=0.047, cb_pad=0.01, cb_tick_values=None, cb_tick_labels=None,
         title='Contributions', titlesize=16, xlabelsize=16, ylabelsize=16, xyticksize=16,
@@ -314,9 +342,9 @@ def plot_contribution_maps(
 
 def get_image_plane_pix_grid(should_plot_image_plane_pix, fit):
 
-    if hasattr(fit, 'mapper'):
-        if should_plot_image_plane_pix and fit.mapper.is_image_plane_pixelization:
-            return fit.tracer.image_plane.grids[0].pix
+    if hasattr(fit, 'inversion'):
+        if should_plot_image_plane_pix and fit.inversion.mapper.is_image_plane_pixelization:
+            return fit.tracer.image_plane.grid_stack.pixelization
     else:
         return None
 
@@ -331,6 +359,16 @@ def get_mask(fit, should_plot_mask):
         If *True*, the masks is plotted on the fit's datas.
     """
     if should_plot_mask:
-        return fit.mask
+        return fit.mask_2d
+    else:
+        return None
+
+def get_mass_profile_centes(plot_mass_profile_centres, fit):
+
+    if not hasattr(fit, 'tracer'):
+        return None
+
+    if plot_mass_profile_centres:
+        return fit.tracer.image_plane.centres_of_galaxy_mass_profiles
     else:
         return None
\ No newline at end of file
