@@ -1,7 +1,4 @@
-import math
-
 import numpy as np
-from astropy import constants
 from astropy import cosmology as cosmo
 from functools import wraps
 
@@ -9,69 +6,10 @@ from autolens import exc
 from autolens.data.array import grids
 from autolens.lens import plane as pl
 from autolens.lens.util import lens_util
+from autolens.model import cosmology_util
+from autolens.model.inversion import inversions as inv
 from autolens.model.inversion import pixelizations as pix
-
-
-def check_tracer_for_redshifts(func):
-    """If a tracer's galaxies do not have redshifts, its cosmological quantities cannot be computed. This wrapper \
-    makes these functions return *None* if the galaxies do not have redshifts
-
-    Parameters
-    ----------
-    func : (self) -> Object
-        A property function that requires galaxies to have redshifts.
-    """
-
-    @wraps(func)
-    def wrapper(self):
-        """
-
-        Parameters
-        ----------
-        self
-
-        Returns
-        -------
-            A value or coordinate in the same coordinate system as those passed in.
-        """
-
-        if self.all_planes_have_redshifts is True:
-            return func(self)
-        else:
-            return None
-
-    return wrapper
-
-
-def check_tracer_for_light_profile(func):
-    """If none of the tracer's galaxies have a light profile, it image-plane image cannot be computed. This wrapper \
-    makes this property return *None*.
-
-    Parameters
-    ----------
-    func : (self) -> Object
-        A property function that requires galaxies to have a mass profile.
-    """
-
-    @wraps(func)
-    def wrapper(self):
-        """
-
-        Parameters
-        ----------
-        self
-
-        Returns
-        -------
-            A value or coordinate in the same coordinate system as those passed in.
-        """
-
-        if self.has_light_profile is True:
-            return func(self)
-        else:
-            return None
-
-    return wrapper
+from autolens.model.galaxy import galaxy as g
 
 
 def check_tracer_for_mass_profile(func):
@@ -115,7 +53,7 @@ class AbstractTracerCosmology(object):
 
         Parameters
         ----------
-        plane_redshifts : [pl.Plane] or [pl.PlaneStack]
+        plane_redshifts : [pl.Plane]
             The list of the tracer's planes in ascending redshift order.
         cosmology : astropy.cosmology
             The cosmology of the ray-tracing calculation.
@@ -127,46 +65,38 @@ class AbstractTracerCosmology(object):
     def total_planes(self):
         return len(self.plane_redshifts)
 
-    @property
-    def constant_kpc(self):
-        # noinspection PyUnresolvedReferences
-        return constants.c.to('kpc / s').value ** 2.0 / (4 * math.pi * constants.G.to('kpc3 / M_sun s2').value)
-
     def arcsec_per_kpc_proper_of_plane(self, i):
-        return self.cosmology.arcsec_per_kpc_proper(z=self.plane_redshifts[i]).value
+        return cosmology_util.arcsec_per_kpc_from_redshift_and_cosmology(redshift=self.plane_redshifts[i],
+                                                                         cosmology=self.cosmology)
 
     def kpc_per_arcsec_proper_of_plane(self, i):
-        return 1.0 / self.arcsec_per_kpc_proper_of_plane(i)
+        return 1.0 / self.arcsec_per_kpc_proper_of_plane(i=i)
 
-    def angular_diameter_distance_of_plane_to_earth(self, i):
-        return self.cosmology.angular_diameter_distance(self.plane_redshifts[i]).to('kpc').value
+    def angular_diameter_distance_of_plane_to_earth_in_units(self, i, unit_length='arcsec'):
+        return cosmology_util.angular_diameter_distance_to_earth_from_redshift_and_cosmology(
+            redshift=self.plane_redshifts[i], cosmology=self.cosmology, unit_length=unit_length)
 
-    def angular_diameter_distance_between_planes(self, i, j):
-        return self.cosmology.angular_diameter_distance_z1z2(self.plane_redshifts[i],
-                                                             self.plane_redshifts[j]).to('kpc').value
+    def angular_diameter_distance_between_planes_in_units(self, i, j, unit_length='arcsec'):
+        return cosmology_util.angular_diameter_distance_between_redshifts_from_redshifts_and_cosmlology(
+            redshift_0=self.plane_redshifts[i], redshift_1=self.plane_redshifts[j], cosmology=self.cosmology,
+            unit_length=unit_length)
 
-    @property
-    def angular_diameter_distance_to_source_plane(self):
-        return self.cosmology.angular_diameter_distance(self.plane_redshifts[-1]).to('kpc').value
+    def angular_diameter_distance_to_source_plane_in_units(self, unit_length='arcsec'):
+        return cosmology_util.angular_diameter_distance_to_earth_from_redshift_and_cosmology(
+            redshift=self.plane_redshifts[-1], cosmology=self.cosmology, unit_length=unit_length)
 
-    def critical_density_kpc_between_planes(self, i, j):
-        return self.constant_kpc * self.angular_diameter_distance_of_plane_to_earth(j) / \
-               (self.angular_diameter_distance_between_planes(i, j) *
-                self.angular_diameter_distance_of_plane_to_earth(i))
-
-    def critical_density_arcsec_between_planes(self, i, j):
-        return self.critical_density_kpc_between_planes(i=i, j=j) * self.kpc_per_arcsec_proper_of_plane(i=i) ** 2.0
+    def critical_surface_density_between_planes_in_units(self, i, j, unit_length='arcsec', unit_mass='solMass'):
+        return cosmology_util.critical_surface_density_between_redshifts_from_redshifts_and_cosmology(
+            redshift_0=self.plane_redshifts[i], redshift_1=self.plane_redshifts[j], cosmology=self.cosmology,
+            unit_length=unit_length, unit_mass=unit_mass)
 
     def scaling_factor_between_planes(self, i, j):
-        return lens_util.scaling_factor_between_redshifts_for_cosmology(z1=self.plane_redshifts[i],
-                                                                        z2=self.plane_redshifts[j],
-                                                                        z_final=self.plane_redshifts[-1],
-                                                                        cosmology=self.cosmology)
+        return cosmology_util.scaling_factor_between_redshifts_from_redshifts_and_cosmology(
+            redshift_0=self.plane_redshifts[i],
+            redshift_1=self.plane_redshifts[j], redshift_final=self.plane_redshifts[-1], cosmology=self.cosmology)
 
-    @property
-    @check_tracer_for_redshifts
-    def angular_diameter_distance_from_image_to_source_plane(self):
-        return self.angular_diameter_distance_between_planes(i=0, j=-1)
+    def angular_diameter_distance_from_image_to_source_plane_in_units(self, unit_length='arcsec'):
+        return self.angular_diameter_distance_between_planes_in_units(i=0, j=-1, unit_length=unit_length)
 
 
 class AbstractTracer(AbstractTracerCosmology):
@@ -179,7 +109,7 @@ class AbstractTracer(AbstractTracerCosmology):
 
         Parameters
         ----------
-        planes : [pl.Plane] or [pl.PlaneStack]
+        planes : [pl.Plane]
             The list of the tracer's planes in ascending redshift order.
         cosmology : astropy.cosmology
             The cosmology of the ray-tracing calculation.
@@ -220,6 +150,10 @@ class AbstractTracer(AbstractTracerCosmology):
     def has_regularization(self):
         return any(list(map(lambda plane: plane.has_regularization, self.planes)))
 
+    @property
+    def has_hyper_galaxy(self):
+        return any(list(map(lambda plane: plane.has_hyper_galaxy, self.planes)))
+
     @property
     def has_padded_grids(self):
         return isinstance(self.planes[0].grids.regular, grids.PaddedRegularGrid)
@@ -229,40 +163,33 @@ class AbstractTracer(AbstractTracerCosmology):
         return list([galaxy for plane in self.planes for galaxy in plane.galaxies])
 
     @property
-    def galaxies_in_planes(self):
-        return list([plane.galaxies for plane in self.planes])
+    def profile_image_plane_image_2d(self):
+        return self.image_plane.grid_stack.scaled_array_2d_from_array_1d(
+            array_1d=self.profile_image_plane_image_1d)
 
     @property
-    @check_tracer_for_light_profile
-    def image_plane_image(self):
-        return self.image_plane.grid_stack.scaled_array_2d_from_array_1d(array_1d=self.image_plane_image_1d)
+    def profile_image_plane_image_2d_for_simulation(self):
+        return sum(self.profile_image_plane_image_2d_of_planes_for_simulation)
 
     @property
-    @check_tracer_for_light_profile
-    def image_plane_image_for_simulation(self):
-        return sum(self.image_plane_image_of_planes_for_simulation)
+    def profile_image_plane_image_2d_of_planes_for_simulation(self):
+        return [plane.profile_image_plane_image_2d_for_simulation for plane in self.planes]
 
     @property
-    def image_plane_image_of_planes_for_simulation(self):
-        return [plane.image_plane_image_for_simulation for plane in self.planes]
+    def profile_image_plane_image_1d(self):
+        return sum(self.profile_image_plane_image_1d_of_planes)
 
     @property
-    @check_tracer_for_light_profile
-    def image_plane_image_1d(self):
-        return sum(self.image_plane_image_1d_of_planes)
+    def profile_image_plane_image_1d_of_planes(self):
+        return [plane.profile_image_plane_image_1d for plane in self.planes]
 
     @property
-    def image_plane_image_1d_of_planes(self):
-        return [plane.image_plane_image_1d for plane in self.planes]
+    def profile_image_plane_blurring_image_1d(self):
+        return sum(self.profile_image_plane_blurring_image_1d_of_planes)
 
     @property
-    @check_tracer_for_light_profile
-    def image_plane_blurring_image_1d(self):
-        return sum(self.image_plane_blurring_image_1d_of_planes)
-
-    @property
-    def image_plane_blurring_image_1d_of_planes(self):
-        return [plane.image_plane_blurring_image_1d for plane in self.planes]
+    def profile_image_plane_blurring_image_1d_of_planes(self):
+        return [plane.profile_image_plane_blurring_image_1d for plane in self.planes]
 
     @property
     def mappers_of_planes(self):
@@ -292,31 +219,11 @@ class AbstractTracer(AbstractTracerCosmology):
     def deflections_x(self):
         return sum([plane.deflections_x for plane in self.planes])
 
-    @property
-    @check_tracer_for_redshifts
-    def critical_surface_mass_density_kpc(self):
-        return self.constant_kpc * self.source_plane.angular_diameter_distance_to_earth / \
-               (self.angular_diameter_distance_from_image_to_source_plane *
-                self.image_plane.angular_diameter_distance_to_earth)
+    def einstein_radius_of_plane_in_units(self, i, unit_length='arcsec'):
+        return self.planes[i].einstein_radius_in_units(unit_length=unit_length)
 
-    @property
-    @check_tracer_for_redshifts
-    def critical_surface_mass_density_arcsec(self):
-        return self.critical_surface_mass_density_kpc * self.image_plane.kpc_per_arcsec_proper ** 2.0
-
-    @property
-    def einstein_radii_arcsec_of_planes(self):
-        return [plane.einstein_radius_arcsec for plane in self.planes]
-
-    @property
-    def einstein_radii_kpc_of_planes(self):
-        return [plane.einstein_radius_kpc for plane in self.planes]
-
-    @property
-    @check_tracer_for_redshifts
-    def einstein_masses_in_solar_masses_of_planes(self):
-        return [plane.einstein_mass_in_mass_units(
-            critical_surface_mass_density_arcsec=self.critical_surface_mass_density_arcsec) for plane in self.planes]
+    def einstein_mass_between_planes_in_units(self, i, j, unit_mass='solMass'):
+        return self.planes[i].einstein_mass_in_units(unit_mass=unit_mass, redshift_source=self.plane_redshifts[j])
 
     def grid_at_redshift_from_image_plane_grid_and_redshift(self, image_plane_grid, redshift):
         """For an input grid of (y,x) arc-second image-plane coordinates, ray-trace the coordinates to any redshift in \
@@ -352,16 +259,16 @@ class AbstractTracer(AbstractTracerCosmology):
 
                 if plane_index > 0:
                     for previous_plane_index in range(plane_index):
-                        scaling_factor = lens_util.scaling_factor_between_redshifts_for_cosmology(
-                            z1=tracer.plane_redshifts[previous_plane_index], z2=redshift,
-                            z_final=tracer.plane_redshifts[-1], cosmology=tracer.cosmology)
+                        scaling_factor = cosmology_util.scaling_factor_between_redshifts_from_redshifts_and_cosmology(
+                            redshift_0=tracer.plane_redshifts[previous_plane_index], redshift_1=redshift,
+                            redshift_final=tracer.plane_redshifts[-1], cosmology=tracer.cosmology)
 
-                        scaled_deflection_stack = lens_util.scaled_deflection_stack_from_plane_and_scaling_factor(
+                        scaled_deflections_stack = lens_util.scaled_deflections_stack_from_plane_and_scaling_factor(
                             plane=tracer.planes[previous_plane_index], scaling_factor=scaling_factor)
 
                         new_grid_stack = \
-                            lens_util.grid_stack_from_deflection_stack(grid_stack=new_grid_stack,
-                                                                       deflection_stack=scaled_deflection_stack)
+                            lens_util.grid_stack_from_deflections_stack(grid_stack=new_grid_stack,
+                                                                        deflections_stack=scaled_deflections_stack)
 
                 # If redshift is before the first plane, no change to image pllane coordinates.
 
@@ -371,53 +278,147 @@ class AbstractTracer(AbstractTracerCosmology):
 
                 return new_grid_stack.regular
 
-    def masses_of_image_plane_galaxies_within_circles_in_mass_units(self, radius):
-        """
-        Compute the total mass of all galaxies in the image-plane within a circle of specified radius, using the \
-        plane's critical surface density to convert this to physical units.
 
-        For a single galaxy, inputting the Einstein Radius should provide an accurate measurement of the Einstein \
-        mass. Use of other radii may be subject to systematic offsets, because lens does not directly measure the \
-        mass of a galaxy beyond the Einstein radius.
+class AbstractTracerData(AbstractTracer):
 
-        For multiple galaxies, the Einstein mass of the entire image-plane is evenly divided across its galaxies. \
-        This could be highly inaccurate and users are recommended to cross-check mass estimates using different radii.
+    def __init__(self, planes, cosmology):
+        """Abstract Ray tracer for lens systems with any number of planes.
 
-        See *galaxy.dimensionless_mass_within_circle* and *mass_profiles.dimensionless_mass_within_circle* for details \
-        of how this is performed.
+        From the galaxies of the tracer's planes, their grid-stack(s) and the cosmology physically derived quantities \
+        (e.g. surface density, angular diameter distances, critical surface densities) can be computed.
 
         Parameters
         ----------
-        radius : float
-            The radius of the circle to compute the dimensionless mass within.
+        planes : [pl.Plane]
+            The list of the tracer's planes in ascending redshift order.
+        cosmology : astropy.cosmology
+            The cosmology of the ray-tracing calculation.
         """
-        return self.image_plane.masses_of_galaxies_within_circles_in_mass_units(radius=radius,
-                        critical_surface_mass_density=self.critical_surface_mass_density_arcsec)
+        super(AbstractTracerData, self).__init__(planes=planes, cosmology=cosmology)
 
-    def masses_of_image_plane_galaxies_within_ellipses_in_mass_units(self, major_axis):
-        """
-        Compute the total mass of all galaxies in this plane within a ellipse of specified major-axis.
+    def blurred_profile_image_plane_image_2d_of_planes_from_convolver_image(self, convolver_image):
+        """Extract the 1D image-plane image and 1D blurring image-plane image of every plane and blur each with the \
+        PSF using a convolver (see ccd.convolution) and then map them back to the 2D array of the original mask.
 
-        For a single galaxy, inputting the Einstein Radius should provide an accurate measurement of the Einstein \
-        mass. Use of other radii may be subject to systematic offsets, because lens does not directly measure the \
-        mass of a galaxy beyond the Einstein radius.
-
-        For multiple galaxies, the Einstein mass of the entire image-plane is evenly divided across its galaxies. \
-        This could be highly inaccurate and users are recommended to cross-check mass estimates using different radii.
-
-        See *galaxy.dimensionless_mass_within_ellipse* and *mass_profiles.dimensionless_mass_within_ellipse* for details
-        of how this is performed.
+        The blurred image of every plane is returned in 2D.
 
         Parameters
         ----------
-        major_axis : float
-            The major-axis of the ellipse to compute the dimensionless mass within.
+        convolver_image : hyper.ccd.convolution.ConvolverImage
+            Class which performs the PSF convolution of a masked image in 1D.
         """
-        return self.image_plane.masses_of_galaxies_within_ellipses_in_mass_units(major_axis=major_axis,
-                                 critical_surface_mass_density=self.critical_surface_mass_density_arcsec)
+
+        blurred_profile_image_plane_images_of_planes_1d = \
+            self.blurred_profile_image_plane_image_1d_of_planes_from_convolver_image(convolver_image=convolver_image)
+
+        return list(map(lambda blurred_profile_image_plane_image_1d:
+                        self.image_plane.grid_stack.scaled_array_2d_from_array_1d(
+                            array_1d=blurred_profile_image_plane_image_1d),
+                        blurred_profile_image_plane_images_of_planes_1d))
+
+    def blurred_profile_image_plane_image_1d_from_convolver_image(self, convolver_image):
+        """Extract the 1D image-plane image and 1D blurring image-plane image of every plane and blur each with the \
+        PSF using a convolver (see ccd.convolution).
+
+        These are summed to give the tracer's overall blurred image-plane image in 1D.
+
+        Parameters
+        ----------
+        convolver_image : hyper.ccd.convolution.ConvolverImage
+            Class which performs the PSF convolution of a masked image in 1D.
+        """
+        return convolver_image.convolve_image(image_array=self.profile_image_plane_image_1d,
+                                              blurring_array=self.profile_image_plane_blurring_image_1d)
+
+    def blurred_profile_image_plane_image_1d_of_planes_from_convolver_image(self, convolver_image):
+        """Extract the 1D image-plane image and 1D blurring image-plane image of every plane and blur each with the \
+        PSF using a convolver (see ccd.convolution).
+
+        The blurred image of every plane is returned in 1D.
+
+        Parameters
+        ----------
+        convolver_image : hyper.ccd.convolution.ConvolverImage
+            Class which performs the PSF convolution of a masked image in 1D.
+        """
+        return [plane.blurred_profile_image_plane_image_1d_from_convolver_image(convolver_image=convolver_image)
+                for plane in self.planes]
+
+    def unmasked_blurred_profile_image_plane_image_from_psf(self, psf):
+
+        if not self.image_plane.has_padded_grid_stack:
+            raise exc.RayTracingException('To retrieve an unmasked image, the grid stack of a plane tracer'
+                                          'must be a padded grid stack')
+
+        return self.image_plane.grid_stack.unmasked_blurred_image_from_psf_and_unmasked_image(
+            psf=psf, unmasked_image_1d=self.profile_image_plane_image_1d)
+
+    def unmasked_blurred_profile_image_plane_image_of_planes_from_psf(self, psf):
+        return [plane.unmasked_blurred_profile_image_plane_image_from_psf(psf=psf) for plane in self.planes]
+
+    def unmasked_blurred_profile_image_plane_image_of_plane_and_galaxies_from_psf(self, psf):
+        return [plane.unmasked_blurred_profile_image_plane_images_of_galaxies_from_psf(psf=psf) for plane in
+                self.planes]
+
+    def inversion_from_image_1d_noise_map_1d_and_convolver_mapping_matrix(self, image_1d, noise_map_1d,
+                                                                          convolver_mapping_matrix):
+
+        if len(self.mappers_of_planes) > 1:
+            raise exc.RayTracingException(
+                'PyAutoLens does not currently support more than one mapper, reglarization and'
+                'therefore inversion per tracer.')
+
+        return inv.Inversion.from_data_1d_mapper_and_regularization(
+            image_1d=image_1d, noise_map_1d=noise_map_1d, convolver=convolver_mapping_matrix,
+            mapper=self.mappers_of_planes[0], regularization=self.regularizations_of_planes[0])
+
+    def hyper_noise_map_1d_from_noise_map_1d(self, noise_map_1d):
+            hyper_noise_maps_1d = self.hyper_noise_maps_1d_of_planes_from_noise_map_1d(noise_map_1d=noise_map_1d)
+            hyper_noise_maps_1d = [hyper_noise_map for hyper_noise_map in hyper_noise_maps_1d if
+                                   hyper_noise_map is not None]
+            return sum(hyper_noise_maps_1d)
+
+    def hyper_noise_maps_1d_of_planes_from_noise_map_1d(self, noise_map_1d):
+        return [plane.hyper_noise_map_1d_from_noise_map_1d(noise_map_1d=noise_map_1d) for plane in self.planes]
+
+    @property
+    def galaxy_image_dict_blank_images(self) -> {g.Galaxy: np.ndarray}:
+        """
+        A dictionary associating galaxies with their corresponding model images
+        """
+
+        galaxy_image_dict = dict()
+
+        for plane in self.planes:
+            for galaxy in plane.galaxies:
+
+                galaxy_image_dict[galaxy] = plane.profile_image_plane_image_1d_of_galaxy(galaxy=galaxy)
+
+        return galaxy_image_dict
 
 
-class TracerImagePlane(AbstractTracer):
+    def galaxy_image_dict_from_convolver_image(self, convolver_image) -> {g.Galaxy: np.ndarray}:
+        """
+        A dictionary associating galaxies with their corresponding model images
+        """
+
+        galaxy_image_dict = dict()
+
+        for plane in self.planes:
+            for galaxy in plane.galaxies:
+
+                profile_image_plane_image_1d = plane.profile_image_plane_image_1d_of_galaxy(galaxy=galaxy)
+                profile_image_plane_blurring_image_1d = plane.profile_image_plane_blurring_image_1d_of_galaxy(galaxy=galaxy)
+
+                blurred_profile_image_pane_image_1d = convolver_image.convolve_image(
+                    image_array=profile_image_plane_image_1d, blurring_array=profile_image_plane_blurring_image_1d)
+
+                galaxy_image_dict[galaxy] = blurred_profile_image_pane_image_1d
+
+        return galaxy_image_dict
+
+
+class TracerImagePlane(AbstractTracerData):
 
     def __init__(self, lens_galaxies, image_plane_grid_stack, border=None, cosmology=cosmo.Planck15):
         """Ray tracer for a lens system with just an image-plane. 
@@ -443,13 +444,16 @@ class TracerImagePlane(AbstractTracer):
         if not lens_galaxies:
             raise exc.RayTracingException('No lens galaxies have been input into the Tracer')
 
-        image_plane = pl.Plane(galaxies=lens_galaxies, grid_stack=image_plane_grid_stack, border=border,
-                               compute_deflections=True, cosmology=cosmology)
+        image_plane = pl.Plane(galaxies=lens_galaxies, grid_stack=image_plane_grid_stack, compute_deflections=False,
+                               border=border, cosmology=cosmology)
 
         super(TracerImagePlane, self).__init__(planes=[image_plane], cosmology=cosmology)
 
+    def critical_surface_density_between_planes_in_units(self, i, j, unit_length='arcsec', unit_mass='solMass'):
+        return 0.0
 
-class TracerImageSourcePlanes(AbstractTracer):
+
+class TracerImageSourcePlanes(AbstractTracerData):
 
     def __init__(self, lens_galaxies, source_galaxies, image_plane_grid_stack, border=None, cosmology=cosmo.Planck15):
         """Ray-tracer for a lens system with two planes, an image-plane and source-plane.
@@ -471,21 +475,34 @@ class TracerImageSourcePlanes(AbstractTracer):
             The cosmology of the ray-tracing calculation.
         """
 
-        image_plane_grid_stack = pix.setup_image_plane_pixelization_grid_from_galaxies_and_grid_stack(
-            galaxies=source_galaxies, grid_stack=image_plane_grid_stack)
-
         image_plane = pl.Plane(galaxies=lens_galaxies, grid_stack=image_plane_grid_stack, border=border,
-                               compute_deflections=True, cosmology=cosmology)
+            compute_deflections=True, cosmology=cosmology)
 
         source_plane_grid_stack = image_plane.trace_grid_stack_to_next_plane()
 
-        source_plane = pl.Plane(galaxies=source_galaxies, grid_stack=source_plane_grid_stack, border=border,
-                                compute_deflections=False, cosmology=cosmology)
+        source_plane = pl.Plane(
+            galaxies=source_galaxies,
+            grid_stack=source_plane_grid_stack,
+            border=border,
+            compute_deflections=False,
+            cosmology=cosmology
+        )
 
         super(TracerImageSourcePlanes, self).__init__(planes=[image_plane, source_plane], cosmology=cosmology)
 
+    def critical_surface_density_between_image_and_source_plane_in_units(self, unit_length='arcsec',
+                                                                         unit_mass='solMass'):
+        return self.critical_surface_density_between_planes_in_units(i=0, j=1, unit_length=unit_length,
+                                                                     unit_mass=unit_mass)
 
-class TracerMultiPlanes(AbstractTracer):
+    def einstein_radius_of_image_plane_in_units(self, unit_length='arcsec'):
+        return self.einstein_radius_of_plane_in_units(i=0, unit_length=unit_length)
+
+    def einstein_mass_between_image_and_source_plane_in_units(self, unit_mass='solMass'):
+        return self.einstein_mass_between_planes_in_units(i=0, j=1, unit_mass=unit_mass)
+
+
+class TracerMultiPlanes(AbstractTracerData):
 
     def __init__(self, galaxies, image_plane_grid_stack, border=None, cosmology=cosmo.Planck15):
         """Ray-tracer for a lens system with any number of planes.
@@ -518,9 +535,6 @@ class TracerMultiPlanes(AbstractTracer):
             lens_util.galaxies_in_redshift_ordered_planes_from_galaxies(galaxies=galaxies,
                                                                         plane_redshifts=plane_redshifts)
 
-        image_plane_grid_stack = pix.setup_image_plane_pixelization_grid_from_galaxies_and_grid_stack(
-            galaxies=galaxies, grid_stack=image_plane_grid_stack)
-
         planes = []
 
         for plane_index in range(0, len(plane_redshifts)):
@@ -532,24 +546,24 @@ class TracerMultiPlanes(AbstractTracer):
 
             if plane_index > 0:
                 for previous_plane_index in range(plane_index):
-                    scaling_factor = lens_util.scaling_factor_between_redshifts_for_cosmology(
-                        z1=plane_redshifts[previous_plane_index], z2=plane_redshifts[plane_index],
-                        z_final=plane_redshifts[-1], cosmology=cosmology)
+                    scaling_factor = cosmology_util.scaling_factor_between_redshifts_from_redshifts_and_cosmology(
+                        redshift_0=plane_redshifts[previous_plane_index], redshift_1=plane_redshifts[plane_index],
+                        redshift_final=plane_redshifts[-1], cosmology=cosmology)
 
-                    scaled_deflection_stack = lens_util.scaled_deflection_stack_from_plane_and_scaling_factor(
+                    scaled_deflections_stack = lens_util.scaled_deflections_stack_from_plane_and_scaling_factor(
                         plane=planes[previous_plane_index], scaling_factor=scaling_factor)
 
                     new_grid_stack = \
-                        lens_util.grid_stack_from_deflection_stack(grid_stack=new_grid_stack,
-                                                                   deflection_stack=scaled_deflection_stack)
+                        lens_util.grid_stack_from_deflections_stack(grid_stack=new_grid_stack,
+                                                                    deflections_stack=scaled_deflections_stack)
 
-            planes.append(pl.Plane(galaxies=galaxies_in_planes[plane_index], grid_stack=new_grid_stack,
-                                   border=border, compute_deflections=compute_deflections, cosmology=cosmology))
+            planes.append(pl.Plane(galaxies=galaxies_in_planes[plane_index], grid_stack=new_grid_stack, border=border,
+                                   compute_deflections=compute_deflections, cosmology=cosmology))
 
         super(TracerMultiPlanes, self).__init__(planes=planes, cosmology=cosmology)
 
 
-class TracerMultiPlanesSliced(AbstractTracer):
+class TracerMultiPlanesSliced(AbstractTracerData):
 
     def __init__(self, lens_galaxies, line_of_sight_galaxies, source_galaxies, planes_between_lenses,
                  image_plane_grid_stack, border=None, cosmology=cosmo.Planck15):
@@ -593,9 +607,6 @@ class TracerMultiPlanesSliced(AbstractTracer):
         plane_redshifts.append(source_galaxies[0].redshift)
         galaxies_in_planes.append(source_galaxies)
 
-        image_plane_grid_stack = pix.setup_image_plane_pixelization_grid_from_galaxies_and_grid_stack(
-            galaxies=lens_galaxies, grid_stack=image_plane_grid_stack)
-
         planes = []
 
         for plane_index in range(0, len(plane_redshifts)):
@@ -606,22 +617,21 @@ class TracerMultiPlanesSliced(AbstractTracer):
             new_grid_stack = image_plane_grid_stack
 
             if plane_index > 0:
-                print()
                 for previous_plane_index in range(plane_index):
-                    scaling_factor = lens_util.scaling_factor_between_redshifts_for_cosmology(
-                        z1=plane_redshifts[previous_plane_index], z2=plane_redshifts[plane_index],
-                        z_final=plane_redshifts[-1], cosmology=cosmology)
+                    scaling_factor = cosmology_util.scaling_factor_between_redshifts_from_redshifts_and_cosmology(
+                        redshift_0=plane_redshifts[previous_plane_index], redshift_1=plane_redshifts[plane_index],
+                        redshift_final=plane_redshifts[-1], cosmology=cosmology)
 
-                    scaled_deflection_stack = lens_util.scaled_deflection_stack_from_plane_and_scaling_factor(
+                    scaled_deflections_stack = lens_util.scaled_deflections_stack_from_plane_and_scaling_factor(
                         plane=planes[previous_plane_index], scaling_factor=scaling_factor)
 
                     new_grid_stack = \
-                        lens_util.grid_stack_from_deflection_stack(grid_stack=new_grid_stack,
-                                                                   deflection_stack=scaled_deflection_stack)
+                        lens_util.grid_stack_from_deflections_stack(grid_stack=new_grid_stack,
+                                                                    deflections_stack=scaled_deflections_stack)
 
-            planes.append(pl.PlaneSlice(redshift=plane_redshifts[plane_index], galaxies=galaxies_in_planes[plane_index],
-                                        grid_stack=new_grid_stack, border=border,
-                                        compute_deflections=compute_deflections, cosmology=cosmology))
+            planes.append(pl.Plane(redshift=plane_redshifts[plane_index], galaxies=galaxies_in_planes[plane_index],
+                                   grid_stack=new_grid_stack, border=border, compute_deflections=compute_deflections,
+                                   cosmology=cosmology))
 
         super(TracerMultiPlanesSliced, self).__init__(planes=planes, cosmology=cosmology)
 
@@ -702,9 +712,9 @@ class TracerMultiPlanesPositions(AbstractTracer):
 
             if plane_index > 0:
                 for previous_plane_index in range(plane_index):
-                    scaling_factor = lens_util.scaling_factor_between_redshifts_for_cosmology(
-                        z1=plane_redshifts[previous_plane_index], z2=plane_redshifts[plane_index],
-                        z_final=plane_redshifts[-1], cosmology=cosmology)
+                    scaling_factor = cosmology_util.scaling_factor_between_redshifts_from_redshifts_and_cosmology(
+                        redshift_0=plane_redshifts[previous_plane_index], redshift_1=plane_redshifts[plane_index],
+                        redshift_final=plane_redshifts[-1], cosmology=cosmology)
 
                     scaled_deflections = list(map(lambda deflections:
                                                   np.multiply(scaling_factor, deflections),
