@@ -1,10 +1,14 @@
-import numpy as np
+import autofit as af
+import matplotlib
+backend = af.conf.instance.visualize.get('figures', 'backend', str)
+matplotlib.use(backend)
 import matplotlib.pyplot as plt
 import matplotlib.cm as cm
+import numpy as np
 import itertools
 from scipy.spatial import Voronoi
 
-from autolens.data.array.plotters import plotter_util, grid_plotters
+from autolens.plotters import plotter_util, grid_plotters
 from autolens.model.inversion import mappers
 from autolens.data.plotters import ccd_plotters
 
@@ -22,7 +26,7 @@ def plot_image_and_mapper(ccd_data, mapper, mask=None, positions=None, should_pl
     ccd_plotters.plot_image(ccd_data=ccd_data, mask=mask, positions=positions, as_subplot=True,
                             units=units, kpc_per_arcsec=None, xyticksize=16,
                             norm='linear', norm_min=None, norm_max=None, linthresh=0.05, linscale=0.01,
-                            figsize=None, aspect='equal', cmap='jet', cb_ticksize=10,
+                            figsize=None, aspect='square', cmap='jet', cb_ticksize=10,
                             titlesize=10, xlabelsize=10, ylabelsize=10,
                             output_path=output_path, output_format=output_format)
 
@@ -98,7 +102,7 @@ def plot_rectangular_mapper(mapper, should_plot_centres=False, should_plot_grid=
                                output_format=output_format)
     plotter_util.close_figure(as_subplot=as_subplot)
 
-def plot_voronoi_mapper(mapper, solution_vector, should_plot_centres=True, should_plot_grid=True, should_plot_border=False,
+def plot_voronoi_mapper(mapper, source_pixel_values, should_plot_centres=True, should_plot_grid=True, should_plot_border=False,
                         image_pixels=None, source_pixels=None, as_subplot=False,
                         units='arcsec', kpc_per_arcsec=None,
                         xyticksize=16, figsize=(7, 7),
@@ -107,16 +111,15 @@ def plot_voronoi_mapper(mapper, solution_vector, should_plot_centres=True, shoul
                         output_path=None, output_filename='voronoi_mapper', output_format='show'):
 
     plotter_util.setup_figure(figsize=figsize, as_subplot=as_subplot)
- #   plt.figaspect(1)
 
     set_axis_limits(mapper=mapper, units=units, kpc_per_arcsec=kpc_per_arcsec)
 
     regions_SP, vertices_SP = voronoi_finite_polygons_2d(mapper.voronoi)
 
-    color_values = solution_vector[:] / np.max(solution_vector)
+    color_values = source_pixel_values[:] / np.max(source_pixel_values)
     cmap = plt.get_cmap('jet')
 
-    set_colorbar(cmap=cmap, color_values=color_values, cb_fraction=cb_fraction, cb_pad=cb_pad,
+    set_colorbar(cmap=cmap, color_values=source_pixel_values, cb_fraction=cb_fraction, cb_pad=cb_pad,
                  cb_tick_values=cb_tick_values, cb_tick_labels=cb_tick_labels)
 
     for region, index in zip(regions_SP, range(mapper.pixels)):
@@ -329,8 +332,8 @@ def plot_image_plane_source_pixels(grid, mapper, source_pixels, point_colors):
         for source_pixel_set in source_pixels:
             color = next(point_colors)
             for source_pixel in source_pixel_set:
-                plt.scatter(y=np.asarray(grid[mapper.pix_to_regular[source_pixel], 0]),
-                            x=np.asarray(grid[mapper.pix_to_regular[source_pixel], 1]), s=8, color=color)
+                plt.scatter(y=np.asarray(grid[mapper.pixelization_to_regular_all[source_pixel], 0]),
+                            x=np.asarray(grid[mapper.pixelization_to_regular_all[source_pixel], 1]), s=8, color=color)
 
 def plot_source_plane_image_pixels(grid, image_pixels, point_colors):
 
@@ -348,8 +351,8 @@ def plot_source_plane_source_pixels(grid, mapper, source_pixels, point_colors):
         for source_pixel_set in source_pixels:
             color = next(point_colors)
             for source_pixel in source_pixel_set:
-                plt.scatter(y=np.asarray(grid[mapper.pix_to_regular[source_pixel], 0]),
-                            x=np.asarray(grid[mapper.pix_to_regular[source_pixel], 1]), s=8, color=color)
+                plt.scatter(y=np.asarray(grid[mapper.pixelization_to_regular_all[source_pixel], 0]),
+                            x=np.asarray(grid[mapper.pixelization_to_regular_all[source_pixel], 1]), s=8, color=color)
 
 def convert_grid(grid, units, kpc_per_arcsec):
 
