@@ -1,9 +1,8 @@
 import os
 
-from autofit import conf
-from autofit.optimize import non_linear as nl
+import autofit as af
 from autolens.model.galaxy import galaxy_model as gm
-from autolens.pipeline import phase as ph
+from autolens.pipeline.phase import phase_imaging
 from autolens.pipeline import pipeline as pl
 from autolens.model.profiles import light_profiles as lp
 from test.integration import integration_util
@@ -15,21 +14,31 @@ test_name = "lens_x1_galaxy"
 test_path = '{}/../../'.format(os.path.dirname(os.path.realpath(__file__)))
 output_path = test_path + 'output/'
 config_path = test_path + 'config'
-conf.instance = conf.Config(config_path=config_path, output_path=output_path)
+af.conf.instance = af.conf.Config(config_path=config_path, output_path=output_path)
 
 def pipeline():
 
-    integration_util.reset_paths(test_name=test_name, output_path=output_path)
-    ccd_data = simulation_util.load_test_ccd_data(data_type='lens_only_dev_vaucouleurs', data_resolution='LSST')
+    integration_util.reset_paths(
+        test_name=test_name, output_path=output_path)
+
+    ccd_data = simulation_util.load_test_ccd_data(
+        data_type='lens_only_dev_vaucouleurs', data_resolution='LSST')
+
     pipeline = make_pipeline(test_name=test_name)
+
     pipeline.run(data=ccd_data)
 
 
 def make_pipeline(test_name):
 
-    phase1 = ph.LensPlanePhase(phase_name='phase_1', phase_folders=[test_type, test_name],
-                               lens_galaxies=dict(lens=gm.GalaxyModel(sersic=lp.EllipticalSersic)),
-                               optimizer_class=nl.MultiNest)
+    phase1 = phase_imaging.LensPlanePhase(
+        phase_name='phase_1',
+        phase_folders=[test_type, test_name],
+        lens_galaxies=dict(
+            lens=gm.GalaxyModel(
+                redshift=0.5,
+                sersic=lp.EllipticalSersic)),
+        optimizer_class=af.MultiNest)
 
     phase1.optimizer.const_efficiency_mode = True
     phase1.optimizer.n_live_points = 40
