@@ -1,9 +1,8 @@
 import os
 
-from autofit import conf
-from autofit.optimize import non_linear as nl
+import autofit as af
 from autolens.model.galaxy import galaxy_model as gm
-from autolens.pipeline import phase as ph
+from autolens.pipeline.phase import phase_positions
 from autolens.pipeline import pipeline as pl
 from autolens.model.profiles import mass_profiles as mp
 from test.integration import integration_util
@@ -14,7 +13,7 @@ test_name = "positions_phase"
 test_path = '{}/../../'.format(os.path.dirname(os.path.realpath(__file__)))
 output_path = test_path + 'output/'
 config_path = test_path + 'config'
-conf.instance = conf.Config(config_path=config_path, output_path=output_path)
+af.conf.instance = af.conf.Config(config_path=config_path, output_path=output_path)
 
 def pipeline():
 
@@ -27,9 +26,10 @@ def pipeline():
 
 def make_pipeline(test_name):
 
-    phase1 = ph.PhasePositions(phase_name="phase1", phase_folders=[test_type, test_name],
-                               lens_galaxies=dict(lens=gm.GalaxyModel(mass=mp.SphericalIsothermal)),
-                               optimizer_class=nl.MultiNest)
+    phase1 = phase_positions.PhasePositions(
+        phase_name="phase1", phase_folders=[test_type, test_name],
+        lens_galaxies=dict(lens=gm.GalaxyModel(redshift=0.5, mass=mp.SphericalIsothermal)),
+        optimizer_class=af.MultiNest)
 
     phase1.optimizer.const_efficiency_mode = True
     phase1.optimizer.n_live_points = 20
