@@ -4,7 +4,7 @@ import numpy as np
 import pytest
 
 from autolens import exc
-from autolens.data.array.util import array_util, grid_util
+from autolens.data.array.util import array_util, grid_util, binning_util
 from autolens.data.array import mask as msk
 from autolens.data.array import scaled_array
 
@@ -676,7 +676,7 @@ class TestScaledSquarePixelArray:
                                             [True, False, False, True],
                                             [True,  True,  True, True]]), pixel_scale=1.0)
 
-            array_extracted = array.extract_scaled_array_around_mask(mask=mask, buffer=0)
+            array_extracted = array.zoomed_scaled_array_around_mask(mask=mask, buffer=0)
             assert (array_extracted == np.array([[6.0,   7.0],
                                                  [10.0, 11.0]])).all()
 
@@ -685,7 +685,7 @@ class TestScaledSquarePixelArray:
                                             [True, False, False, False],
                                             [True,  True,  True, True]]), pixel_scale=1.0)
 
-            array_extracted = array.extract_scaled_array_around_mask(mask=mask, buffer=0)
+            array_extracted = array.zoomed_scaled_array_around_mask(mask=mask, buffer=0)
             assert (array_extracted == np.array([[6.0,   7.0,  8.0],
                                                  [10.0, 11.0, 12.0]])).all()
 
@@ -694,7 +694,7 @@ class TestScaledSquarePixelArray:
                                             [True, False, False, True],
                                             [True,  True, False, True]]), pixel_scale=1.0)
 
-            array_extracted = array.extract_scaled_array_around_mask(mask=mask, buffer=0)
+            array_extracted = array.zoomed_scaled_array_around_mask(mask=mask, buffer=0)
             assert (array_extracted == np.array([[6.0,   7.0],
                                                  [10.0, 11.0],
                                                  [14.0, 15.0]])).all()
@@ -704,8 +704,7 @@ class TestScaledSquarePixelArray:
                                             [False, False, False, True],
                                             [True,  True,  True, True]]), pixel_scale=1.0)
 
-            array_extracted = array.extract_scaled_array_around_mask(mask=mask, buffer=0)
-            print(array_extracted)
+            array_extracted = array.zoomed_scaled_array_around_mask(mask=mask, buffer=0)
             assert (array_extracted == np.array([[5.0,  6.0,  7.0],
                                                  [9.0, 10.0, 11.0]])).all()
 
@@ -714,7 +713,7 @@ class TestScaledSquarePixelArray:
                                             [True, False, False, True],
                                             [True,  True,  True, True]]), pixel_scale=1.0)
     
-            array_extracted = array.extract_scaled_array_around_mask(mask=mask, buffer=0)
+            array_extracted = array.zoomed_scaled_array_around_mask(mask=mask, buffer=0)
             assert (array_extracted == np.array([[2.0,   3.0],
                                                  [6.0,   7.0],
                                                  [10.0, 11.0]])).all()
@@ -724,7 +723,7 @@ class TestScaledSquarePixelArray:
                                             [True, False, False, True],
                                             [True,  True,  True, True]]), pixel_scale=1.0)
 
-            array_extracted = array.extract_scaled_array_around_mask(mask=mask, buffer=1)
+            array_extracted = array.zoomed_scaled_array_around_mask(mask=mask, buffer=1)
             assert (array_extracted == np.array([[ 1.0,  2.0,  3.0,  4.0],
                                                  [ 5.0,  6.0,  7.0,  8.0],
                                                  [ 9.0, 10.0, 11.0, 12.0],
@@ -740,15 +739,15 @@ class TestScaledSquarePixelArray:
 
             array_2d = scaled_array.ScaledSquarePixelArray(array=array_2d, pixel_scale=0.1)
 
-            binned_up_array_2d_util = array_util.bin_up_array_2d_using_mean(array_2d=array_2d, bin_up_factor=4)
+            binned_up_array_2d_util = binning_util.binned_up_array_2d_using_mean_from_array_2d_and_bin_up_factor(array_2d=array_2d, bin_up_factor=4)
             binned_up_scaled_array = array_2d.binned_up_array_from_array(bin_up_factor=4, method='mean')
             assert (binned_up_array_2d_util == binned_up_scaled_array).all()
 
-            binned_up_array_2d_util = array_util.bin_up_array_2d_using_quadrature(array_2d=array_2d, bin_up_factor=4)
+            binned_up_array_2d_util = binning_util.binned_array_2d_using_quadrature_from_array_2d_and_bin_up_factor(array_2d=array_2d, bin_up_factor=4)
             binned_up_scaled_array = array_2d.binned_up_array_from_array(bin_up_factor=4, method='quadrature')
             assert (binned_up_array_2d_util == binned_up_scaled_array).all()
 
-            binned_up_array_2d_util = array_util.bin_up_array_2d_using_sum(array_2d=array_2d, bin_up_factor=4)
+            binned_up_array_2d_util = binning_util.binned_array_2d_using_sum_from_array_2d_and_bin_up_factor(array_2d=array_2d, bin_up_factor=4)
             binned_up_scaled_array = array_2d.binned_up_array_from_array(bin_up_factor=4, method='sum')
             assert (binned_up_array_2d_util == binned_up_scaled_array).all()
 
@@ -782,7 +781,7 @@ class TestScaledSquarePixelArray:
                                  [1.0, 2.0, 3.0, 4.0, 5.0, 6.0]])
 
             array_2d = scaled_array.ScaledSquarePixelArray(array=array_2d, pixel_scale=0.1)
-            with pytest.raises(exc.ImagingException):
+            with pytest.raises(exc.DataException):
                 array_2d.binned_up_array_from_array(bin_up_factor=4, method='wrong')
 
 
