@@ -137,7 +137,7 @@ class TestMap2DArrayTo1d(object):
                          [True, False, True],
                          [True, True, True]])
 
-        array_1d = mapping_util.map_2d_array_to_masked_1d_array_from_array_2d_and_mask(mask, array_2d)
+        array_1d = mapping_util.map_array_2d_to_masked_array_1d_from_array_2d_and_mask(mask, array_2d)
 
         assert (array_1d == np.array([5])).all()
 
@@ -150,7 +150,7 @@ class TestMap2DArrayTo1d(object):
                          [False, False, False],
                          [True, False, True]])
 
-        array_1d = mapping_util.map_2d_array_to_masked_1d_array_from_array_2d_and_mask(mask, array_2d)
+        array_1d = mapping_util.map_array_2d_to_masked_array_1d_from_array_2d_and_mask(mask, array_2d)
 
         assert (array_1d == np.array([2, 4, 5, 6, 8])).all()
 
@@ -163,7 +163,7 @@ class TestMap2DArrayTo1d(object):
                          [False, False, False, True],
                          [True, False, True, False]])
 
-        array_1d = mapping_util.map_2d_array_to_masked_1d_array_from_array_2d_and_mask(mask, array_2d)
+        array_1d = mapping_util.map_array_2d_to_masked_array_1d_from_array_2d_and_mask(mask, array_2d)
 
         assert (array_1d == np.array([2, 5, 6, 7, 10, 12])).all()
 
@@ -178,11 +178,175 @@ class TestMap2DArrayTo1d(object):
                          [True, False, True],
                          [True, True, True]])
 
-        array_1d = mapping_util.map_2d_array_to_masked_1d_array_from_array_2d_and_mask(mask, array_2d)
+        array_1d = mapping_util.map_array_2d_to_masked_array_1d_from_array_2d_and_mask(mask, array_2d)
 
         assert (array_1d == np.array([2, 4, 5, 6, 8])).all()
 
 
+class TestMap2DGridTo1d(object):
+
+    def test__setup_3x3_data(self):
+        
+        grid_2d = np.array([[[1, 1], [2, 2], [3, 3]],
+                             [[4, 4], [5, 5], [6, 6]],
+                             [[7, 7], [8, 8], [9, 9]]])
+
+        mask = np.array([[True, True, True],
+                         [True, False, True],
+                         [True, True, True]])
+
+        grid_1d = mapping_util.map_grid_2d_to_masked_grid_1d_from_grid_2d_and_mask(mask=mask, grid_2d=grid_2d)
+
+        assert (grid_1d == np.array([[5, 5]])).all()
+
+    def test__setup_3x3_grid__five_now_in_mask(self):
+
+        grid_2d = np.array([[[1, 1], [2, 2], [3, 3]],
+                            [[4, 4], [5, 5], [6, 6]],
+                            [[7, 7], [8, 8], [9, 9]]])
+
+        mask = np.array([[True, False, True],
+                         [False, False, False],
+                         [True, False, True]])
+
+        grid_1d = mapping_util.map_grid_2d_to_masked_grid_1d_from_grid_2d_and_mask(mask=mask, grid_2d=grid_2d)
+
+        assert (grid_1d == np.array([[2,2], [4,4], [5,5], [6,6], [8,8]])).all()
+
+    def test__setup_3x4_grid(self):
+
+        grid_2d = np.array([[[1,1], [2,2], [3,3], [4,4]],
+                             [[5,5], [6,6], [7,7], [8,8]],
+                             [[9,9], [10,10], [11,11], [12,12]]])
+
+        mask = np.array([[True, False, True, True],
+                         [False, False, False, True],
+                         [True, False, True, False]])
+
+        grid_1d = mapping_util.map_grid_2d_to_masked_grid_1d_from_grid_2d_and_mask(mask=mask, grid_2d=grid_2d)
+
+        assert (grid_1d == np.array([[2,2], [5,5], [6,6], [7,7], [10,10], [12,12]])).all()
+
+    def test__setup_4x3_grid__five_now_in_mask(self):
+
+        grid_2d = np.array([[[1, 1], [2, 2], [3, 3]],
+                            [[4, 4], [5, 5], [6, 6]],
+                            [[7, 7], [8, 8], [9, 9]],
+                            [[10, 10], [11,11], [12,12]]])
+
+        mask = np.array([[True, False, True],
+                         [False, False, False],
+                         [True, False, True],
+                         [True, True, True]])
+
+        grid_1d = mapping_util.map_grid_2d_to_masked_grid_1d_from_grid_2d_and_mask(mask=mask, grid_2d=grid_2d)
+
+        assert (grid_1d == np.array([[2,2], [4,4], [5,5], [6,6], [8,8]])).all()
+
+
+class TestMap2DSubArrayTo1D(object):
+    
+    def test__setup_3x3_data__sub_grid_size_1(self):
+
+        sub_array_2d = np.array([[1, 2, 3],
+                                 [4, 5, 6],
+                                 [7, 8, 9]])
+
+        mask = np.array([[True, True, True],
+                         [True, False, True],
+                         [True, True, True]])
+
+        sub_array_1d = mapping_util.map_sub_array_2d_to_masked_sub_array_1d_from_sub_array_2d_mask_and_sub_grid_size(
+            sub_array_2d=sub_array_2d, mask=mask, sub_grid_size=1)
+
+        assert (sub_array_1d == np.array([5])).all()
+
+    def test__setup_3x3_data__sub_grid_size_2(self):
+
+        sub_array_2d = np.array([[1,  2,  3,   4,  5,  6],
+                                 [7,  8,  9,  10, 11, 12],
+                                 [13, 14, 15, 16, 17, 18],
+                                 [1,   2,  3,  4,  5,  6],
+                                 [7,   8,  9, 10, 11, 12],
+                                 [13, 14, 15, 16, 17, 18]])
+
+        mask = np.array([[True, True, True],
+                         [True, False, True],
+                         [True, True, True]])
+
+        sub_array_1d = mapping_util.map_sub_array_2d_to_masked_sub_array_1d_from_sub_array_2d_mask_and_sub_grid_size(
+            sub_array_2d=sub_array_2d, mask=mask, sub_grid_size=2)
+
+        assert (sub_array_1d == np.array([15, 16, 3, 4])).all()
+
+        mask = np.array([[True, False, True],
+                         [True, False, True],
+                         [True, True, False]])
+
+        sub_array_1d = mapping_util.map_sub_array_2d_to_masked_sub_array_1d_from_sub_array_2d_mask_and_sub_grid_size(
+            sub_array_2d=sub_array_2d, mask=mask, sub_grid_size=2)
+
+        assert (sub_array_1d == np.array([3, 4, 9, 10, 15, 16, 3, 4, 11, 12, 17, 18])).all()
+
+
+    def test__setup_3x4_sub_array(self):
+
+        sub_array_2d = np.array([[1,  2,  3,   4,  5,  6, 7, 7, 7],
+                                 [7,  8,  9,  10, 11, 12, 7, 7, 7],
+                                 [13, 14, 15, 16, 17, 18, 7, 7, 7],
+                                 [1,   2,  3,  4,  5,  6, 7, 7, 7],
+                                 [7,   8,  9, 10, 11, 12, 7, 7, 7],
+                                 [13, 14, 15, 16, 17, 18, 7, 7, 7]])
+
+        mask = np.array([[True, False, True, True],
+                         [False, False, False, True],
+                         [True, False, True, False]])
+
+        sub_array_1d = mapping_util.map_sub_array_2d_to_masked_sub_array_1d_from_sub_array_2d_mask_and_sub_grid_size(
+            sub_array_2d=sub_array_2d, mask=mask, sub_grid_size=2)
+
+        assert (sub_array_1d == np.array([3, 4, 9, 10, 13, 14, 1, 2, 15, 16, 3, 4, 17, 18, 5, 6, 9, 10, 15, 16, 7, 7, 7, 7])).all()
+
+    def test__setup_4x3_sub_array__five_now_in_mask(self):
+
+        sub_array_2d = np.array([[1,  2,  3,   4,  5,  6],
+                                 [7,  8,  9,  10, 11, 12],
+                                 [13, 14, 15, 16, 17, 18],
+                                 [1,   2,  3,  4,  5,  6],
+                                 [7,   8,  9, 10, 11, 12],
+                                 [13, 14, 15, 16, 17, 18],
+                                 [7,   7,  7,  7,  7,  7],
+                                 [7,   7,  7,  7,  7,  7]])
+
+        mask = np.array([[True, False, True],
+                         [False, False, False],
+                         [True, False, True],
+                         [True, True, True]])
+
+        sub_array_1d = mapping_util.map_sub_array_2d_to_masked_sub_array_1d_from_sub_array_2d_mask_and_sub_grid_size(
+            sub_array_2d=sub_array_2d, mask=mask, sub_grid_size=2)
+
+        assert (sub_array_1d == np.array([3, 4, 9, 10, 13, 14, 1, 2, 15, 16, 3, 4, 17, 18, 5, 6, 9, 10, 15, 16])).all()
+
+
+    def test__setup_2x2_data__sub_grid_size_3(self):
+
+        sub_array_2d = np.array([[1,  2,  3,   4,  5,  6],
+                                 [7,  8,  9,  10, 11, 12],
+                                 [13, 14, 15, 16, 17, 18],
+                                 [1,   2,  3,  4,  5,  6],
+                                 [7,   8,  9, 10, 11, 12],
+                                 [13, 14, 15, 16, 17, 18]])
+
+        mask = np.array([[False, True],
+                         [True, False]])
+
+        sub_array_1d = mapping_util.map_sub_array_2d_to_masked_sub_array_1d_from_sub_array_2d_mask_and_sub_grid_size(
+            sub_array_2d=sub_array_2d, mask=mask, sub_grid_size=3)
+
+        assert (sub_array_1d == np.array([1, 2, 3, 7, 8, 9, 13, 14, 15, 4, 5, 6, 10, 11, 12, 16, 17, 18])).all()
+
+
 class TestMapMasked1DArrayTo2d(object):
 
     def test__2d_array_is_2x2__is_not_masked__maps_correctly(self):
@@ -191,7 +355,7 @@ class TestMapMasked1DArrayTo2d(object):
         one_to_two = np.array([[0, 0], [0, 1], [1, 0], [1, 1]])
         shape = (2, 2)
 
-        array_2d = mapping_util.map_masked_1d_array_to_2d_array_from_array_1d_shape_and_one_to_two(array_1d, shape, one_to_two)
+        array_2d = mapping_util.map_masked_array_1d_to_array_2d_from_array_1d_shape_and_one_to_two(array_1d, shape, one_to_two)
 
         assert (array_2d == np.array([[1.0, 2.0],
                                       [3.0, 4.0]])).all()
@@ -202,7 +366,7 @@ class TestMapMasked1DArrayTo2d(object):
         one_to_two = np.array([[0, 0], [0, 1], [1, 0]])
         shape = (2, 2)
 
-        array_2d = mapping_util.map_masked_1d_array_to_2d_array_from_array_1d_shape_and_one_to_two(array_1d, shape, one_to_two)
+        array_2d = mapping_util.map_masked_array_1d_to_array_2d_from_array_1d_shape_and_one_to_two(array_1d, shape, one_to_two)
 
         assert (array_2d == np.array([[1.0, 2.0],
                                       [3.0, 0.0]])).all()
@@ -213,13 +377,53 @@ class TestMapMasked1DArrayTo2d(object):
         one_to_two = np.array([[0, 0], [0, 1], [1, 0], [2, 0], [2, 1], [2, 3]])
         shape = (3, 4)
 
-        array_2d = mapping_util.map_masked_1d_array_to_2d_array_from_array_1d_shape_and_one_to_two(array_1d, shape, one_to_two)
+        array_2d = mapping_util.map_masked_array_1d_to_array_2d_from_array_1d_shape_and_one_to_two(array_1d, shape, one_to_two)
 
         assert (array_2d == np.array([[1.0, 2.0, 0.0, 0.0],
                                       [3.0, 0.0, 0.0, 0.0],
                                       [-1.0, -2.0, 0.0, -3.0]])).all()
 
 
+class TestMapMasked1DGridTo2d(object):
+
+    def test__2d_grid_is_2x2__is_not_masked__maps_correctly(self):
+        
+        grid_1d = np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]])
+
+        one_to_two = np.array([[0, 0], [0, 1], [1, 0], [1, 1]])
+        shape = (2, 2)
+
+        grid_2d = mapping_util.map_masked_1d_grid_to_2d_grid_from_grid_1d_shape_and_one_to_two(grid_1d, shape, one_to_two)
+
+        assert (grid_2d == np.array([[[1.0, 1.0], [2.0, 2.0]],
+                                     [[3.0, 3.0], [4.0, 4.0]]])).all()
+
+    def test__2d_grid_is_2x2__is_masked__maps_correctly(self):
+
+        grid_1d = np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 4.0]])
+
+        one_to_two = np.array([[0, 0], [0, 1], [1, 0]])
+        shape = (2, 2)
+
+        grid_2d = mapping_util.map_masked_1d_grid_to_2d_grid_from_grid_1d_shape_and_one_to_two(grid_1d, shape, one_to_two)
+
+        assert (grid_2d == np.array([[[1.0, 1.0], [2.0, 2.0]],
+                                      [[3.0, 4.0], [0.0, 0.0]]])).all()
+
+    def test__different_shape_and_mappings(self):
+
+        grid_1d = np.array([[1.0, -1.0], [2.0, -2.0], [3.0, -3.0], [-1.0, 1.0], [-2.0, 2.0], [-3.0, 3.0]])
+
+        one_to_two = np.array([[0, 0], [0, 1], [1, 0], [2, 0], [2, 1], [2, 3]])
+        shape = (3, 4)
+
+        grid_2d = mapping_util.map_masked_1d_grid_to_2d_grid_from_grid_1d_shape_and_one_to_two(grid_1d, shape, one_to_two)
+
+        assert (grid_2d == np.array([[[1.0, -1.0], [2.0, -2.0], [0.0, 0.0], [0.0, 0.0]],
+                                      [[3.0, -3.0], [0.0, 0.0], [0.0, 0.0], [0.0, 0.0]],
+                                      [[-1.0, 1.0], [-2.0, 2.0], [0.0, 0.0], [-3.0, 3.0]]])).all()
+
+
 class TestMapUnmasked1dArrayTo2d(object):
 
     def test__1d_array_in__maps_it_to_4x4_2d_array(self):
