@@ -1,9 +1,8 @@
 from os import path
 
 import pytest
-from autofit import exc
+import autofit as af
 
-from autofit import conf
 from autolens.model.profiles import light_profiles
 
 directory = path.dirname(path.realpath(__file__))
@@ -15,7 +14,7 @@ class MockClass(object):
 
 @pytest.fixture(name="label_config")
 def make_label_config():
-    return conf.LabelConfig("{}/test_files/configs/config/label.ini".format(directory))
+    return af.conf.instance.label
 
 
 class TestLabel(object):
@@ -34,5 +33,5 @@ class TestLabel(object):
         assert label_config.subscript(light_profiles.EllipticalGaussian) == "l"
 
     def test_exception(self, label_config):
-        with pytest.raises(exc.PriorException):
+        with pytest.raises(af.exc.PriorException):
             label_config.subscript(MockClass)
