@@ -10,7 +10,6 @@ from autolens.data.array import grids
 from autolens.model.galaxy import galaxy
 from autolens.model.profiles import light_profiles
 from autolens.model.profiles import mass_profiles
-from autolens.lens import ray_tracing
 
 def weighted_avg_and_std(values, weights):
     """
@@ -211,9 +210,9 @@ class SLACS(object):
                 sample_weights.append(self.pdf.weights[i])
 
                 radius_arc = radius_kpc * self.arcsec_per_kpc
-                bulge_mass =  self.critical_density_arcsec * self.lens_galaxy.bulge.mass_within_circle_in_angular_units(radius=radius_arc)
-                disk_mass = self.critical_density_arcsec * self.lens_galaxy.disk.mass_within_circle_in_angular_units(radius=radius_arc)
-                halo_mass = self.critical_density_arcsec * self.lens_galaxy.halo.mass_within_circle_in_angular_units(radius=radius_arc)
+                bulge_mass =  self.critical_density_arcsec * self.lens_galaxy.bulge.mass_within_circle_in_units(radius=radius_arc)
+                disk_mass = self.critical_density_arcsec * self.lens_galaxy.disk.mass_within_circle_in_units(radius=radius_arc)
+                halo_mass = self.critical_density_arcsec * self.lens_galaxy.halo.mass_within_circle_in_units(radius=radius_arc)
 
                 total_mass = bulge_mass + disk_mass + halo_mass
                 stellar_mass = (bulge_mass + disk_mass)
@@ -265,14 +264,14 @@ class SLACS(object):
                     values = self.pdf.samples[i]
                     self.setup_lensing_plane_ltm2r(values)
 
-                    bulge_density = self.critical_density_arcsec * (self.lens_galaxy.bulge.mass_within_circle_in_angular_units(radii[r + 1]) -
-                                                                    self.lens_galaxy.bulge.mass_within_circle_in_angular_units(radii[r])) / annuli_area
+                    bulge_density = self.critical_density_arcsec * (self.lens_galaxy.bulge.mass_within_circle_in_units(radii[r + 1]) -
+                                                                    self.lens_galaxy.bulge.mass_within_circle_in_units(radii[r])) / annuli_area
 
-                    disk_density = self.critical_density_arcsec * (self.lens_galaxy.disk.mass_within_circle_in_angular_units(radii[r + 1]) -
-                                                                   self.lens_galaxy.disk.mass_within_circle_in_angular_units(radii[r])) / annuli_area
+                    disk_density = self.critical_density_arcsec * (self.lens_galaxy.disk.mass_within_circle_in_units(radii[r + 1]) -
+                                                                   self.lens_galaxy.disk.mass_within_circle_in_units(radii[r])) / annuli_area
 
-                    halo_density = self.critical_density_arcsec * (self.lens_galaxy.halo.mass_within_circle_in_angular_units(radii[r + 1]) -
-                                                                   self.lens_galaxy.halo.mass_within_circle_in_angular_units(radii[r])) / annuli_area
+                    halo_density = self.critical_density_arcsec * (self.lens_galaxy.halo.mass_within_circle_in_units(radii[r + 1]) -
+                                                                   self.lens_galaxy.halo.mass_within_circle_in_units(radii[r])) / annuli_area
 
                     bulge_densities.append(bulge_density)
                     halo_densities.append(disk_density)
