@@ -27,7 +27,7 @@ class SLACS(object):
         self.source_light_min = 0.1
         self.source_light_max = 2.5
 
-        self.arcsec_per_kpc = cosmological_model.arcsec_per_kpc_proper(self.redshift).value
+        self.arcsec_per_kpc = cosmological_model.arcsec_per_kpc(self.redshift).value
         self.kpc_per_arcsec = 1.0/self.arcsec_per_kpc
 
         # stop
@@ -162,8 +162,8 @@ class SLACS(object):
 
             self.setup_lensing_plane_sie(values)
 
-            sie_density = self.critical_density_arcsec * (self.lens_galaxy.sie.mass_within_circle_in_angular_units(radii[r + 1]) -
-                                                          self.lens_galaxy.sie.mass_within_circle_in_angular_units(radii[r])) / annuli_area
+            sie_density = self.critical_density_arcsec * (self.lens_galaxy.sie.mass_within_circle_in_units(radii[r + 1]) -
+                                                          self.lens_galaxy.sie.mass_within_circle_in_units(radii[r])) / annuli_area
 
             self.sie_density_plot.append(sie_density)
 
@@ -205,14 +205,14 @@ class SLACS(object):
             elif gradient is 'envelope':
                 self.setup_lensing_plane_ltm2r_envelope(values, center_skip, ltm_skip)
 
-            bulge_density = self.critical_density_arcsec * (self.lens_galaxy.bulge.mass_within_circle_in_angular_units(radii[r + 1]) -
-                                                            self.lens_galaxy.bulge.mass_within_circle_in_angular_units(radii[r])) / annuli_area
+            bulge_density = self.critical_density_arcsec * (self.lens_galaxy.bulge.mass_within_circle_in_units(radii[r + 1]) -
+                                                            self.lens_galaxy.bulge.mass_within_circle_in_units(radii[r])) / annuli_area
 
-            envelope_density = self.critical_density_arcsec * (self.lens_galaxy.envelope.mass_within_circle_in_angular_units(radii[r + 1]) -
-                                                               self.lens_galaxy.envelope.mass_within_circle_in_angular_units(radii[r])) / annuli_area
+            envelope_density = self.critical_density_arcsec * (self.lens_galaxy.envelope.mass_within_circle_in_units(radii[r + 1]) -
+                                                               self.lens_galaxy.envelope.mass_within_circle_in_units(radii[r])) / annuli_area
 
-            halo_density = self.critical_density_arcsec * (self.lens_galaxy.halo.mass_within_circle_in_angular_units(radii[r + 1]) -
-                                                           self.lens_galaxy.halo.mass_within_circle_in_angular_units(radii[r])) / annuli_area
+            halo_density = self.critical_density_arcsec * (self.lens_galaxy.halo.mass_within_circle_in_units(radii[r + 1]) -
+                                                           self.lens_galaxy.halo.mass_within_circle_in_units(radii[r])) / annuli_area
 
             self.bulge_density_plot.append(bulge_density)
             self.envelope_density_plot.append(envelope_density)
@@ -280,7 +280,7 @@ class SLACS(object):
         self.setup_lensing_plane_sie(values=values)
 
         radius_arc = radius_kpc * self.arcsec_per_kpc
-        sie_mass =  self.critical_density_arcsec * self.lens_galaxy.sie.mass_within_circle_in_angular_units(radius=radius_arc)
+        sie_mass =  self.critical_density_arcsec * self.lens_galaxy.sie.mass_within_circle_in_units(radius=radius_arc)
 
         return sie_mass
 
@@ -289,9 +289,9 @@ class SLACS(object):
         self.setup_lensing_plane_ltm2(values=values, center_skip=center_skip, ltm_skip=ltm_skip)
 
         radius_arc = radius_kpc * self.arcsec_per_kpc
-        bulge_mass =  self.critical_density_arcsec * self.lens_galaxy.bulge.mass_within_circle_in_angular_units(radius=radius_arc)
-        envelope_mass = self.critical_density_arcsec * self.lens_galaxy.envelope.mass_within_circle_in_angular_units(radius=radius_arc)
-        halo_mass = self.critical_density_arcsec * self.lens_galaxy.halo.mass_within_circle_in_angular_units(radius=radius_arc)
+        bulge_mass =  self.critical_density_arcsec * self.lens_galaxy.bulge.mass_within_circle_in_units(radius=radius_arc)
+        envelope_mass = self.critical_density_arcsec * self.lens_galaxy.envelope.mass_within_circle_in_units(radius=radius_arc)
+        halo_mass = self.critical_density_arcsec * self.lens_galaxy.halo.mass_within_circle_in_units(radius=radius_arc)
 
         total_mass = bulge_mass + envelope_mass + halo_mass
         stellar_mass = (bulge_mass + envelope_mass)
@@ -304,9 +304,9 @@ class SLACS(object):
         self.setup_lensing_plane_ltm2r_bulge(values=values, center_skip=center_skip, ltm_skip=ltm_skip)
 
         radius_arc = radius_kpc * self.arcsec_per_kpc
-        bulge_mass =  self.critical_density_arcsec * self.lens_galaxy.bulge.mass_within_circle_in_angular_units(radius=radius_arc)
-        envelope_mass = self.critical_density_arcsec * self.lens_galaxy.envelope.mass_within_circle_in_angular_units(radius=radius_arc)
-        halo_mass = self.critical_density_arcsec * self.lens_galaxy.halo.mass_within_circle_in_angular_units(radius=radius_arc)
+        bulge_mass =  self.critical_density_arcsec * self.lens_galaxy.bulge.mass_within_circle_in_units(radius=radius_arc)
+        envelope_mass = self.critical_density_arcsec * self.lens_galaxy.envelope.mass_within_circle_in_units(radius=radius_arc)
+        halo_mass = self.critical_density_arcsec * self.lens_galaxy.halo.mass_within_circle_in_units(radius=radius_arc)
 
         total_mass = bulge_mass + envelope_mass + halo_mass
         stellar_mass = (bulge_mass + envelope_mass)
@@ -319,9 +319,9 @@ class SLACS(object):
         self.setup_lensing_plane_ltm2r_envelope(values=values, center_skip=center_skip, ltm_skip=ltm_skip)
 
         radius_arc = radius_kpc * self.arcsec_per_kpc
-        bulge_mass =  self.critical_density_arcsec * self.lens_galaxy.bulge.mass_within_circle_in_angular_units(radius=radius_arc)
-        envelope_mass = self.critical_density_arcsec * self.lens_galaxy.envelope.mass_within_circle_in_angular_units(radius=radius_arc)
-        halo_mass = self.critical_density_arcsec * self.lens_galaxy.halo.mass_within_circle_in_angular_units(radius=radius_arc)
+        bulge_mass =  self.critical_density_arcsec * self.lens_galaxy.bulge.mass_within_circle_in_units(radius=radius_arc)
+        envelope_mass = self.critical_density_arcsec * self.lens_galaxy.envelope.mass_within_circle_in_units(radius=radius_arc)
+        halo_mass = self.critical_density_arcsec * self.lens_galaxy.halo.mass_within_circle_in_units(radius=radius_arc)
 
         total_mass = bulge_mass + envelope_mass + halo_mass
         stellar_mass = (bulge_mass + envelope_mass)
