@@ -9,7 +9,7 @@ from autolens.lens.util import lens_fit_util
 from workspace_jam.scraps.stack import ray_tracing_stack, lens_data_stack as lds, lens_fit_stack
 from autolens.model.profiles import light_profiles as lp
 from autolens.model.profiles import mass_profiles as mp
-from test.unit.mock.mock_profiles import MockLightProfile
+from test.unit.mock.model.mock_profiles import MockLightProfile
 
 @pytest.fixture(name='lens_data_stack_blur')
 def make_li_blur_stack():
