@@ -8,8 +8,8 @@ from autolens.model.galaxy.util import galaxy_util
 from autolens.lens.util import lens_util
 from workspace_jam.scraps.stack import plane_stack as pl_stack
 from autolens.model.profiles import light_profiles as lp, mass_profiles as mp
-from test.unit.mock.mock_inversion import MockRegularization, MockPixelization
-from test.unit.mock.mock_imaging import MockBorders
+from test.unit.mock.model.mock_inversion import MockRegularization, MockPixelization
+from test.unit.mock.data.mock_grids import MockBorders
 
 @pytest.fixture(name="grid_stack_0")
 def make_grid_stack_0():
@@ -396,7 +396,7 @@ class TestPlaneStack:
 
             mp = galaxy_mass.mass_profiles[0]
 
-            mp_sub_image = mp.convergence_from_grid(grid_stack_0.sub.unlensed_grid)
+            mp_sub_image = mp.convergence_from_grid(grid_stack_0.sub.unlensed_sub_grid)
 
             # Perform sub gridding average manually
             mp_image_pixel_0 = (mp_sub_image[0] + mp_sub_image[1] + mp_sub_image[2] + mp_sub_image[3]) / 4
@@ -414,7 +414,7 @@ class TestPlaneStack:
 
             mp = galaxy_mass.mass_profiles[0]
 
-            mp_sub_image = mp.potential_from_grid(grid_stack_0.sub.unlensed_grid)
+            mp_sub_image = mp.potential_from_grid(grid_stack_0.sub.unlensed_sub_grid)
 
             # Perform sub gridding average manually
             mp_image_pixel_0 = (mp_sub_image[0] + mp_sub_image[1] + mp_sub_image[2] + mp_sub_image[3]) / 4
@@ -432,7 +432,7 @@ class TestPlaneStack:
 
             mp = galaxy_mass.mass_profiles[0]
 
-            mp_sub_image = mp.deflections_from_grid(grid_stack_0.sub.unlensed_grid)
+            mp_sub_image = mp.deflections_from_grid(grid_stack_0.sub.unlensed_sub_grid)
 
             # Perform sub gridding average manually
             mp_image_pixel_0x = (mp_sub_image[0 ,0] + mp_sub_image[1, 0] + mp_sub_image[2, 0] + mp_sub_image[3, 0]) / 4
