@@ -144,13 +144,13 @@ class TestTracerImagePlaneStack(object):
 
             tracer_0 = ray_tracing.TracerImagePlane(lens_galaxies=[g0, g1, g2], image_plane_grid_stack=grid_stack_0)
 
-            assert (tracer_stack.image_plane_images[0] == tracer_0.image_plane_image).all()
-            assert (tracer_stack.image_plane_blurring_images_1d[0] == tracer_0.image_plane_blurring_image_1d).all()
+            assert (tracer_stack.image_plane_images[0] == tracer_0.profile_image_plane_image_2d).all()
+            assert (tracer_stack.image_plane_blurring_images_1d[0] == tracer_0.profile_image_plane_blurring_image_1d).all()
 
             tracer_1 = ray_tracing.TracerImagePlane(lens_galaxies=[g0, g1, g2], image_plane_grid_stack=grid_stack_1)
 
-            assert (tracer_stack.image_plane_images[1] == tracer_1.image_plane_image).all()
-            assert (tracer_stack.image_plane_blurring_images_1d[1] == tracer_1.image_plane_blurring_image_1d).all()
+            assert (tracer_stack.image_plane_images[1] == tracer_1.profile_image_plane_image_2d).all()
+            assert (tracer_stack.image_plane_blurring_images_1d[1] == tracer_1.profile_image_plane_blurring_image_1d).all()
 
 
 class TestTracerImageSourcePlanesStack(object):
@@ -260,15 +260,15 @@ class TestTracerImageSourcePlanesStack(object):
                                                                                        padded_grid_stack])
 
             image_plane_image_2d = \
-                padded_grid_stack.regular.map_to_2d_keep_padded(tracer.image_plane.image_plane_images_1d[0]) + \
-                padded_grid_stack.regular.map_to_2d_keep_padded(tracer.source_plane.image_plane_images_1d[0])
+                padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(tracer.image_plane.image_plane_images_1d[0]) + \
+                padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(tracer.source_plane.image_plane_images_1d[0])
 
             assert image_plane_image_2d.shape == (3, 4)
             assert (image_plane_image_2d == tracer.image_plane_images_for_simulation[0]).all()
 
             image_plane_image_2d = \
-                padded_grid_stack.regular.map_to_2d_keep_padded(tracer.image_plane.image_plane_images_1d[1]) + \
-                padded_grid_stack.regular.map_to_2d_keep_padded(tracer.source_plane.image_plane_images_1d[1])
+                padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(tracer.image_plane.image_plane_images_1d[1]) + \
+                padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(tracer.source_plane.image_plane_images_1d[1])
 
             assert image_plane_image_2d.shape == (3, 4)
             assert (image_plane_image_2d == tracer.image_plane_images_for_simulation[1]).all()
@@ -352,7 +352,7 @@ class TestTracerImageSourcePlanesStack(object):
                                                                                                    sub_grid_size=1,
                                                                                                    psf_shape=(1, 1))
 
-            galaxy = g.Galaxy(pixelization=pixelizations.AdaptiveMagnification(shape=(3, 3)),
+            galaxy = g.Galaxy(pixelization=pixelizations.VoronoiMagnification(shape=(3, 3)),
                               regularization=regularization.Constant())
 
             tracer = ray_tracing_stack.TracerImageSourcePlanesStack(lens_galaxies=[galaxy], source_galaxies=[galaxy],
@@ -369,7 +369,7 @@ class TestTracerImageSourcePlanesStack(object):
             grid_stack_0 = grids.GridStack.grid_stack_from_mask_sub_grid_size_and_psf_shape(mask=ma, sub_grid_size=1,
                                                                                             psf_shape=(1, 1))
 
-            galaxy = g.Galaxy(pixelization=pixelizations.AdaptiveMagnification(shape=(3, 3)),
+            galaxy = g.Galaxy(pixelization=pixelizations.VoronoiMagnification(shape=(3, 3)),
                               regularization=regularization.Constant())
 
             tracer = ray_tracing_stack.TracerImageSourcePlanesStack(lens_galaxies=[galaxy], source_galaxies=[galaxy],
@@ -404,14 +404,14 @@ class TestTracerImageSourcePlanesStack(object):
             tracer_0 = ray_tracing.TracerImageSourcePlanes(lens_galaxies=[g0, g1, g2], source_galaxies=[g0, g1],
                                                            image_plane_grid_stack=grid_stack_0)
 
-            assert (tracer_stack.image_plane_images[0] == tracer_0.image_plane_image).all()
-            assert (tracer_stack.image_plane_blurring_images_1d[0] == tracer_0.image_plane_blurring_image_1d).all()
+            assert (tracer_stack.image_plane_images[0] == tracer_0.profile_image_plane_image_2d).all()
+            assert (tracer_stack.image_plane_blurring_images_1d[0] == tracer_0.profile_image_plane_blurring_image_1d).all()
 
             tracer_1 = ray_tracing.TracerImageSourcePlanes(lens_galaxies=[g0, g1, g2], source_galaxies=[g0, g1],
                                                            image_plane_grid_stack=grid_stack_1)
 
-            assert (tracer_stack.image_plane_images[1] == tracer_1.image_plane_image).all()
-            assert (tracer_stack.image_plane_blurring_images_1d[1] == tracer_1.image_plane_blurring_image_1d).all()
+            assert (tracer_stack.image_plane_images[1] == tracer_1.profile_image_plane_image_2d).all()
+            assert (tracer_stack.image_plane_blurring_images_1d[1] == tracer_1.profile_image_plane_blurring_image_1d).all()
 
 
 class TestMultiTracerStack(object):
@@ -749,7 +749,7 @@ class TestMultiTracerStack(object):
                                                                                                    sub_grid_size=1,
                                                                                                    psf_shape=(1, 1))
 
-            galaxy = g.Galaxy(pixelization=pixelizations.AdaptiveMagnification(shape=(3, 3)),
+            galaxy = g.Galaxy(pixelization=pixelizations.VoronoiMagnification(shape=(3, 3)),
                               regularization=regularization.Constant(), redshift=2.0)
 
             tracer = ray_tracing_stack.TracerMultiPlanesStack(galaxies=[galaxy, g.Galaxy(redshift=1.0)],
@@ -769,7 +769,7 @@ class TestMultiTracerStack(object):
             grid_stack_0 = grids.GridStack.grid_stack_from_mask_sub_grid_size_and_psf_shape(mask=ma, sub_grid_size=1,
                                                                                             psf_shape=(1, 1))
 
-            galaxy = g.Galaxy(pixelization=pixelizations.AdaptiveMagnification(shape=(3, 3)),
+            galaxy = g.Galaxy(pixelization=pixelizations.VoronoiMagnification(shape=(3, 3)),
                               regularization=regularization.Constant(), redshift=2.0)
 
             tracer = ray_tracing_stack.TracerMultiPlanesStack(galaxies=[galaxy, g.Galaxy(redshift=1.0)],
@@ -804,11 +804,11 @@ class TestMultiTracerStack(object):
             tracer_0 = ray_tracing.TracerMultiPlanes(galaxies=[g0, g1, g2, g3, g4],
                                                      image_plane_grid_stack=grid_stack_0)
 
-            assert (tracer_stack.image_plane_images[0] == tracer_0.image_plane_image).all()
-            assert (tracer_stack.image_plane_blurring_images_1d[0] == tracer_0.image_plane_blurring_image_1d).all()
+            assert (tracer_stack.image_plane_images[0] == tracer_0.profile_image_plane_image_2d).all()
+            assert (tracer_stack.image_plane_blurring_images_1d[0] == tracer_0.profile_image_plane_blurring_image_1d).all()
 
             tracer_1 = ray_tracing.TracerMultiPlanes(galaxies=[g0, g1, g2, g3, g4],
                                                      image_plane_grid_stack=grid_stack_1)
 
-            assert (tracer_stack.image_plane_images[1] == tracer_1.image_plane_image).all()
-            assert (tracer_stack.image_plane_blurring_images_1d[1] == tracer_1.image_plane_blurring_image_1d).all()
\ No newline at end of file
+            assert (tracer_stack.image_plane_images[1] == tracer_1.profile_image_plane_image_2d).all()
+            assert (tracer_stack.image_plane_blurring_images_1d[1] == tracer_1.profile_image_plane_blurring_image_1d).all()
\ No newline at end of file
