@@ -145,26 +145,30 @@ class TestBlurredImageOfPlanes:
 
         blurred_lens_image_0 = convolver_blur_0.convolve_image(image_array=tracer.image_plane.image_plane_images_1d[0],
                                                            blurring_array=tracer.image_plane.image_plane_blurring_images_1d[0])
-        blurred_lens_image_0 = data_grid_stack_0.regular.scaled_array_2d_from_array_1d(array_1d=blurred_lens_image_0)
+        blurred_lens_image_0 = data_grid_stack_0.regular.scaled_array_2d_from_array_1d(
+            array_1d=blurred_lens_image_0)
 
         blurred_source_image_0 = convolver_blur_0.convolve_image(image_array=tracer.source_plane.image_plane_images_1d[0],
                                                              blurring_array=tracer.source_plane.image_plane_blurring_images_1d[0])
-        blurred_source_image_0 = data_grid_stack_0.regular.scaled_array_2d_from_array_1d(array_1d=blurred_source_image_0)
+        blurred_source_image_0 = data_grid_stack_0.regular.scaled_array_2d_from_array_1d(
+            array_1d=blurred_source_image_0)
 
         blurred_lens_image_1 = convolver_blur_1.convolve_image(image_array=tracer.image_plane.image_plane_images_1d[1],
                                                            blurring_array=tracer.image_plane.image_plane_blurring_images_1d[1])
-        blurred_lens_image_1 = data_grid_stack_1.regular.scaled_array_2d_from_array_1d(array_1d=blurred_lens_image_1)
+        blurred_lens_image_1 = data_grid_stack_1.regular.scaled_array_2d_from_array_1d(
+            array_1d=blurred_lens_image_1)
 
         blurred_source_image_1 = convolver_blur_1.convolve_image(image_array=tracer.source_plane.image_plane_images_1d[1],
                                                              blurring_array=tracer.source_plane.image_plane_blurring_images_1d[1])
-        blurred_source_image_1 = data_grid_stack_1.regular.scaled_array_2d_from_array_1d(array_1d=blurred_source_image_1)
+        blurred_source_image_1 = data_grid_stack_1.regular.scaled_array_2d_from_array_1d(
+            array_1d=blurred_source_image_1)
 
         blurred_images_of_planes = stack_util.blurred_images_of_images_and_planes_from_1d_images_and_convolver(
             total_planes=tracer.total_planes, image_plane_images_1d_of_planes=tracer.image_plane_images_1d_of_planes,
             image_plane_blurring_images_1d_of_planes=tracer.image_plane_blurring_images_1d_of_planes,
             convolvers=[convolver_blur_0, convolver_blur_1],
-            map_to_scaled_arrays=[data_grid_stack_0.regular.array_2d_from_array_1d,
-                                  data_grid_stack_1.regular.array_2d_from_array_1d])
+            map_to_scaled_arrays=[data_grid_stack_0.regular.trimmed_array_2d_from_padded_array_1d,
+                                  data_grid_stack_1.regular.trimmed_array_2d_from_padded_array_1d])
 
         assert (blurred_images_of_planes[0][0] == blurred_lens_image_0).all()
         assert (blurred_images_of_planes[0][1] == blurred_source_image_0).all()
@@ -233,12 +237,12 @@ class TestUnmaskedModelImageOfDatasAndPlanes:
                                                          image_plane_grid_stacks=[padded_grid_stack, padded_grid_stack])
 
         manual_blurred_image_0 = tracer.image_plane.image_plane_images_1d[0]
-        manual_blurred_image_0 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_0 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_0)
         manual_blurred_image_0 = psf_0.convolve(array=manual_blurred_image_0)
 
         manual_blurred_image_1 = tracer.image_plane.image_plane_images_1d[1]
-        manual_blurred_image_1 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_1 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_1)
         manual_blurred_image_1 = psf_1.convolve(array=manual_blurred_image_1)
 
@@ -276,22 +280,22 @@ class TestUnmaskedModelImageOfDatasAndPlanes:
                                                          image_plane_grid_stacks=[padded_grid_stack, padded_grid_stack])
 
         manual_blurred_image_00 = tracer.image_plane.image_plane_images_1d_of_galaxies[0][0]
-        manual_blurred_image_00 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_00 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_00)
         manual_blurred_image_00 = psf_0.convolve(array=manual_blurred_image_00)
 
         manual_blurred_image_01 = tracer.image_plane.image_plane_images_1d_of_galaxies[0][1]
-        manual_blurred_image_01 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_01 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_01)
         manual_blurred_image_01 = psf_0.convolve(array=manual_blurred_image_01)
 
         manual_blurred_image_10 = tracer.image_plane.image_plane_images_1d_of_galaxies[1][0]
-        manual_blurred_image_10 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_10 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_10)
         manual_blurred_image_10 = psf_1.convolve(array=manual_blurred_image_10)
 
         manual_blurred_image_11 = tracer.image_plane.image_plane_images_1d_of_galaxies[1][1]
-        manual_blurred_image_11 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_11 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_11)
         manual_blurred_image_11 = psf_1.convolve(array=manual_blurred_image_11)
 
@@ -331,22 +335,22 @@ class TestUnmaskedModelImageOfDatasAndPlanes:
                                                                                          padded_grid_stack])
 
         manual_blurred_image_i0 = tracer.image_plane.image_plane_images_1d[0]
-        manual_blurred_image_i0 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_i0 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_i0)
         manual_blurred_image_i0 = psf_0.convolve(array=manual_blurred_image_i0)
 
         manual_blurred_image_i1 = tracer.image_plane.image_plane_images_1d[1]
-        manual_blurred_image_i1 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_i1 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_i1)
         manual_blurred_image_i1 = psf_1.convolve(array=manual_blurred_image_i1)
 
         manual_blurred_image_s0 = tracer.source_plane.image_plane_images_1d[0]
-        manual_blurred_image_s0 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_s0 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_s0)
         manual_blurred_image_s0 = psf_0.convolve(array=manual_blurred_image_s0)
 
         manual_blurred_image_s1 = tracer.source_plane.image_plane_images_1d[1]
-        manual_blurred_image_s1 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_s1 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_s1)
         manual_blurred_image_s1 = psf_1.convolve(array=manual_blurred_image_s1)
 
@@ -393,42 +397,42 @@ class TestUnmaskedModelImageOfDatasAndPlanes:
                                                                                          padded_grid_stack])
 
         manual_blurred_image_i00 = tracer.image_plane.image_plane_images_1d_of_galaxies[0][0]
-        manual_blurred_image_i00 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_i00 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_i00)
         manual_blurred_image_i00 = psf_0.convolve(array=manual_blurred_image_i00)
 
         manual_blurred_image_i01 = tracer.image_plane.image_plane_images_1d_of_galaxies[0][1]
-        manual_blurred_image_i01 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_i01 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_i01)
         manual_blurred_image_i01 = psf_0.convolve(array=manual_blurred_image_i01)
 
         manual_blurred_image_i10 = tracer.image_plane.image_plane_images_1d_of_galaxies[1][0]
-        manual_blurred_image_i10 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_i10 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_i10)
         manual_blurred_image_i10 = psf_1.convolve(array=manual_blurred_image_i10)
 
         manual_blurred_image_i11 = tracer.image_plane.image_plane_images_1d_of_galaxies[1][1]
-        manual_blurred_image_i11 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_i11 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_i11)
         manual_blurred_image_i11 = psf_1.convolve(array=manual_blurred_image_i11)
 
         manual_blurred_image_s00 = tracer.source_plane.image_plane_images_1d_of_galaxies[0][0]
-        manual_blurred_image_s00 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_s00 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_s00)
         manual_blurred_image_s00 = psf_0.convolve(array=manual_blurred_image_s00)
 
         manual_blurred_image_s01 = tracer.source_plane.image_plane_images_1d_of_galaxies[0][1]
-        manual_blurred_image_s01 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_s01 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_s01)
         manual_blurred_image_s01 = psf_0.convolve(array=manual_blurred_image_s01)
 
         manual_blurred_image_s10 = tracer.source_plane.image_plane_images_1d_of_galaxies[1][0]
-        manual_blurred_image_s10 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_s10 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_s10)
         manual_blurred_image_s10 = psf_1.convolve(array=manual_blurred_image_s10)
 
         manual_blurred_image_s11 = tracer.source_plane.image_plane_images_1d_of_galaxies[1][1]
-        manual_blurred_image_s11 = padded_grid_stack.regular.map_to_2d_keep_padded(
+        manual_blurred_image_s11 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
             padded_array_1d=manual_blurred_image_s11)
         manual_blurred_image_s11 = psf_1.convolve(array=manual_blurred_image_s11)
 
@@ -530,19 +534,23 @@ class TestUnmaskedModelImageOfDatasPlanesAndGalaxies:
                                                          image_plane_grid_stacks=[padded_grid_stack, padded_grid_stack])
 
         manual_blurred_image_00 = tracer.image_plane.image_plane_images_1d_of_galaxies[0][0]
-        manual_blurred_image_00 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_00)
+        manual_blurred_image_00 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_00)
         manual_blurred_image_00 = psf_0.convolve(array=manual_blurred_image_00)
 
         manual_blurred_image_01 = tracer.image_plane.image_plane_images_1d_of_galaxies[0][1]
-        manual_blurred_image_01 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_01)
+        manual_blurred_image_01 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_01)
         manual_blurred_image_01 = psf_0.convolve(array=manual_blurred_image_01)
 
         manual_blurred_image_10 = tracer.image_plane.image_plane_images_1d_of_galaxies[1][0]
-        manual_blurred_image_10 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_10)
+        manual_blurred_image_10 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_10)
         manual_blurred_image_10 = psf_1.convolve(array=manual_blurred_image_10)
 
         manual_blurred_image_11 = tracer.image_plane.image_plane_images_1d_of_galaxies[1][1]
-        manual_blurred_image_11 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_11)
+        manual_blurred_image_11 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_11)
         manual_blurred_image_11 = psf_1.convolve(array=manual_blurred_image_11)
 
         unmasked_blurred_image_of_datas_planes_and_galaxies = \
@@ -580,36 +588,44 @@ class TestUnmaskedModelImageOfDatasPlanesAndGalaxies:
                                                                 image_plane_grid_stacks=[padded_grid_stack, padded_grid_stack])
 
         manual_blurred_image_i00 = tracer.image_plane.image_plane_images_1d_of_galaxies[0][0]
-        manual_blurred_image_i00 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_i00)
+        manual_blurred_image_i00 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_i00)
         manual_blurred_image_i00 = psf_0.convolve(array=manual_blurred_image_i00)
 
         manual_blurred_image_i01 = tracer.image_plane.image_plane_images_1d_of_galaxies[0][1]
-        manual_blurred_image_i01 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_i01)
+        manual_blurred_image_i01 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_i01)
         manual_blurred_image_i01 = psf_0.convolve(array=manual_blurred_image_i01)
 
         manual_blurred_image_i10 = tracer.image_plane.image_plane_images_1d_of_galaxies[1][0]
-        manual_blurred_image_i10 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_i10)
+        manual_blurred_image_i10 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_i10)
         manual_blurred_image_i10 = psf_1.convolve(array=manual_blurred_image_i10)
 
         manual_blurred_image_i11 = tracer.image_plane.image_plane_images_1d_of_galaxies[1][1]
-        manual_blurred_image_i11 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_i11)
+        manual_blurred_image_i11 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_i11)
         manual_blurred_image_i11 = psf_1.convolve(array=manual_blurred_image_i11)
         
 
         manual_blurred_image_s00 = tracer.source_plane.image_plane_images_1d_of_galaxies[0][0]
-        manual_blurred_image_s00 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_s00)
+        manual_blurred_image_s00 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_s00)
         manual_blurred_image_s00 = psf_0.convolve(array=manual_blurred_image_s00)
 
         manual_blurred_image_s01 = tracer.source_plane.image_plane_images_1d_of_galaxies[0][1]
-        manual_blurred_image_s01 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_s01)
+        manual_blurred_image_s01 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_s01)
         manual_blurred_image_s01 = psf_0.convolve(array=manual_blurred_image_s01)
 
         manual_blurred_image_s10 = tracer.source_plane.image_plane_images_1d_of_galaxies[1][0]
-        manual_blurred_image_s10 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_s10)
+        manual_blurred_image_s10 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_s10)
         manual_blurred_image_s10 = psf_1.convolve(array=manual_blurred_image_s10)
 
         manual_blurred_image_s11 = tracer.source_plane.image_plane_images_1d_of_galaxies[1][1]
-        manual_blurred_image_s11 = padded_grid_stack.regular.map_to_2d_keep_padded(padded_array_1d=manual_blurred_image_s11)
+        manual_blurred_image_s11 = padded_grid_stack.regular.padded_array_2d_from_padded_array_1d(
+            padded_array_1d=manual_blurred_image_s11)
         manual_blurred_image_s11 = psf_1.convolve(array=manual_blurred_image_s11)
 
         unmasked_blurred_image_of_datas_planes_and_galaxies = \
